Deprecated API
Contents
- Terminally Deprecated
- Interfaces
- Classes
- Exception Classes
- Fields
- Methods
- Constructors
- Enum Constants
-
Terminally Deprecated Elements
-
Deprecated Interfaces
-
Deprecated ClassesClassDescriptionSee
RubyModule.discoverInstanceVariables()for the working versionUseJarBootstrapMaininstead.since 9.4since 9.3since 9.4UseMaininstead.replaced withMonomorphicCallSite
-
Deprecated Exception Classes
-
Deprecated FieldsFieldDescriptionexternal access to global object flags is going awayexternal access to global object flags is going awayexternal access to global object flags is going awayexternal access to global object flags is going awayexternal access to global object flags is going awayexternal access to global object flags is going awayexternal access to global object flags is going awayexternal access to global object flags is going awayexternal access to global object flags is going away
-
Deprecated MethodsMethodDescriptionThis method is deprecated and only used by the deprecated AbstractScript cache logic.Use
RubyBigDecimal.sign(ThreadContext)instead.kept due AR-JDBC (uses RubyClass.newInstance(...) to 'fast' allocate a Date instance)internal Date.new!internal Date.new!internal Date.new!internal Date.new!org.jruby.gen.org$jruby$javasupport$ext$JavaLangReflect$Method$POPULATOR.populate(RubyModule, Class) org.jruby.gen.org$jruby$javasupport$ext$JavaTime$LocalDateTime$POPULATOR.populate(RubyModule, Class) org.jruby.gen.org$jruby$javasupport$ext$JavaTime$ZonedDateTime$POPULATOR.populate(RubyModule, Class) org.jruby.gen.org$jruby$javasupport$Java$ByteArrayProxyMethods$POPULATOR.populate(RubyModule, Class) org.jruby.gen.org$jruby$javasupport$proxy$JavaProxyConstructor$POPULATOR.populate(RubyModule, Class) UseRubyModule.defineConstant(ThreadContext, String, IRubyObject)with a reference to Object.UseAccess.integerClass(ThreadContext)instead.UseRubyModule.defineConstantsFrom(ThreadContext, Class)instead.UseError.argumentError(ThreadContext, int, int)instead.Use the versions with zero, one, or two args.Use the versions with zero, one, or two args.UseRubyArray.at(ThreadContext, IRubyObject)instead.Use the versions with zero, one, or two args.RubyArray implements List, use it directlyUse the versions with zero, one, or two args.Use the versions with zero, one, or two args.UseRubyArray.toJavaArray(ThreadContext)instead.external access to global object flags is going awayUseRubyBasicObject.hash(ThreadContext)instead.external access to global object flags is going awayUseRubyBasicObject.to_s(ThreadContext)instead.UseRubyClass.reifiedClass()instead.Use finvoke if you do not want visibility-checking or invokeFrom if you do.Use finvoke if you do not want visibility-checking or invokeFrom if you do.Use finvoke if you do not want visibility-checking or invokeFrom if you do.Use finvoke if you do not want visibility-checking or invokeFrom if you do.Use finvoke if you do not want visibility-checking or invokeFrom if you do.Use finvoke if you do not want visibility-checking or invokeFrom if you do.Use finvoke if you do not want visibility-checking or invokeFrom if you do.Use finvoke if you do not want visibility-checking or invokeFrom if you do.Use finvoke if you do not want visibility-checking or invokeFrom if you do.Use finvoke if you do not want visibility-checking or invokeFrom if you do.UseRubyClass.allocator(ObjectAllocator)instead.UseRubyClass.marshalWith(ObjectMarshal)instead.UseRubyClass.reifiedClass(Class)instead.no longer usedno longer usedUseRubyInteger.numToUint(ThreadContext, IRubyObject)instead.UseRubyIO.binmode(ThreadContext)instead.UseRubyIO.sync_set(ThreadContext, IRubyObject)instead.UseRubyModule.defineAnnotatedConstant(ThreadContext, Field)instead.UseRubyModule.defineConstants(ThreadContext, Class)instead.UseRubyModule.defineMethods(ThreadContext, Class[])and organize your method definitions where you only specify the .class and not needing to add a name as a discriminator. This method is fairly inefficient since it is rescanning the class for all methods to find a single version.UseRubyModule.defineMethods(ThreadContext, Class[])instead and organize your code around all JRubyMethod annotations in that .class being defined.UseRubyModule.defineMethods(ThreadContext, Class[])instead.UseRubyModule.baseName(String)instead.UseRubyModule.superClass(RubyClass)instead.UseRubyModule.undefMethods(ThreadContext, String...)instead.UseRubyNumeric.coerce(ThreadContext, IRubyObject)instead.UseConvert.asInteger(ThreadContext, double)instead.UseConvert.asFloat(ThreadContext, long)instead.UseRubyNumeric.asDouble(ThreadContext)instead.UseRubyNumeric.asInt(ThreadContext)instead.UseRubyNumeric.asLong(ThreadContext)instead.UseConvert.asFixnum(ThreadContext, long)instead.UseRubyNumeric.isNegativeNumber(ThreadContext)instead.UseRubyNumeric.isPositiveNumber(ThreadContext)instead.UseRubyNumeric.isZero(ThreadContext)instead.UseConvert.toDouble(ThreadContext, IRubyObject)instead.UseConvert.toDouble(ThreadContext, IRubyObject)instead.no longer used - uses Java's System.outfromMethod is now finalUSeRubyRational.asDouble(ThreadContext)instead.UseCreate.newStruct(ThreadContext, RubyClass, Block)instead.This method is deprecated and does nothing.UseRubySymbol.length(ThreadContext)instead.Prefer version that receives ByteBuffer rather than recreating every time.useRubyThread.waitForObject(Object, double)and siblingsUseRubyTime.invalidUTCOffset(ThreadContext)insteadUseRubyTime.invalidUTCOffset(ThreadContext)insteaduseRubyTime.getMicros()insteaduseRubyTime.setMicros(int)insteadUseRubyTime.zone(ThreadContext)instead.UseIRubyObject.checkStringType()instead.org.jruby.runtime.Helpers.invoke(ThreadContext, IRubyObject, String, IRubyObject[], CallType, Block) Use finvoke if you do not want visibility-checking or invokeFrom if you do.Use finvoke if you do not want visibility-checking or invokeFrom if you do.Use finvoke if you do not want visibility-checking or invokeFrom if you do.use the trivially-inlinable static versionuse the trivially-inlinable static versionThis was only used by Module#const_defined, but was difficult to match MRI's equivalent in this formOpens a new input stream to read the contents of a resource and returns it. Note that implementations may be allocating native memory for the stream, so callers need to close this when they are done with it. users of this method should follow the pattern: close the stream where you open it.useFileResource.openChannel(int, int)insteadprefer usingLoggerFactory.getLogger(java.lang.Class)if possible
-
Deprecated Constructors
-
Deprecated Enum Constants