Package org.jruby

Class JarBootstrapMain

java.lang.Object
org.jruby.JarBootstrapMain

@Deprecated(since="10.0.3.0", forRemoval=true) public class JarBootstrapMain extends Object
Deprecated, for removal: This API element is subject to removal in a future version.
Use JarBootstrapMain instead.
  • Field Summary

    Fields
    Modifier and Type
    Field
    Description
    static final String
    Deprecated, for removal: This API element is subject to removal in a future version.
     
  • Constructor Summary

    Constructors
    Constructor
    Description
    Deprecated, for removal: This API element is subject to removal in a future version.
     
  • Method Summary

    Modifier and Type
    Method
    Description
    static void
    main(String[] args)
    Deprecated, for removal: This API element is subject to removal in a future version.
     

    Methods inherited from class java.lang.Object

    clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
  • Field Details

    • JAR_BOOTSTRAP

      public static final String JAR_BOOTSTRAP
      Deprecated, for removal: This API element is subject to removal in a future version.
      See Also:
  • Constructor Details

    • JarBootstrapMain

      public JarBootstrapMain()
      Deprecated, for removal: This API element is subject to removal in a future version.
  • Method Details

    • main

      public static void main(String[] args)
      Deprecated, for removal: This API element is subject to removal in a future version.