java.lang.Object
org.jruby.Main
Deprecated.
-
Nested Class Summary
Nested Classes -
Constructor Summary
ConstructorsConstructorDescriptionMain()Deprecated.Main(InputStream in, PrintStream out, PrintStream err) Deprecated.Main(RubyInstanceConfig config) Deprecated. -
Method Summary
Modifier and TypeMethodDescriptionstatic voidDeprecated.This is the command-line entry point for JRuby, and should ONLY be used by Java when starting up JRuby from a command-line.static voidDeprecated.Deprecated.
-
Constructor Details
-
Main
Deprecated. -
Main
Deprecated. -
Main
public Main()Deprecated.
-
-
Method Details
-
processDotfile
public static void processDotfile()Deprecated. -
main
Deprecated.This is the command-line entry point for JRuby, and should ONLY be used by Java when starting up JRuby from a command-line. Use other mechanisms when embedding JRuby into another application.- Parameters:
args- command-line args, provided by the JVM.
-
run
Deprecated.
-
Maininstead.