java.lang.Object
org.jruby.RubyFileTest.FileTestFileMethods
- Enclosing class:
RubyFileTest
MRI defines the FileTest methods both as module functions on FileTest and
as singleton methods on the File class. Since our annotations can't be
both module and singleton method definitions, we define proxies here for
File.
Note that these are to be defined on the singleton class of the File
class.
-
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionstatic IRubyObjectblockdev_p(IRubyObject recv, IRubyObject filename) Deprecated.static IRubyObjectblockdev_p(ThreadContext context, IRubyObject recv, IRubyObject filename) static IRubyObjectchardev_p(IRubyObject recv, IRubyObject filename) Deprecated.static IRubyObjectchardev_p(ThreadContext context, IRubyObject recv, IRubyObject filename) static IRubyObjectdirectory_p(ThreadContext context, IRubyObject recv, IRubyObject filename) static IRubyObjectexecutable_p(IRubyObject recv, IRubyObject filename) Deprecated.static IRubyObjectexecutable_p(ThreadContext context, IRubyObject recv, IRubyObject filename) static IRubyObjectexecutable_real_p(IRubyObject recv, IRubyObject filename) Deprecated.static IRubyObjectexecutable_real_p(ThreadContext context, IRubyObject recv, IRubyObject filename) static IRubyObjectexist_p(ThreadContext context, IRubyObject recv, IRubyObject filename) static RubyBooleanfile_p(ThreadContext context, IRubyObject recv, IRubyObject filename) static IRubyObjectgrpowned_p(IRubyObject recv, IRubyObject filename) Deprecated.static IRubyObjectgrpowned_p(ThreadContext context, IRubyObject recv, IRubyObject filename) static IRubyObjectidentical_p(IRubyObject recv, IRubyObject filename1, IRubyObject filename2) Deprecated.static IRubyObjectidentical_p(ThreadContext context, IRubyObject recv, IRubyObject filename1, IRubyObject filename2) static IRubyObjectowned_p(IRubyObject recv, IRubyObject filename) Deprecated.static IRubyObjectowned_p(ThreadContext context, IRubyObject recv, IRubyObject filename) static IRubyObjectpipe_p(IRubyObject recv, IRubyObject filename) Deprecated.static IRubyObjectpipe_p(ThreadContext context, IRubyObject recv, IRubyObject filename) static IRubyObjectreadable_p(ThreadContext context, IRubyObject recv, IRubyObject filename) static IRubyObjectsetgid_p(IRubyObject recv, IRubyObject filename) Deprecated.static IRubyObjectsetgid_p(ThreadContext context, IRubyObject recv, IRubyObject filename) static IRubyObjectsetuid_p(IRubyObject recv, IRubyObject filename) Deprecated.static IRubyObjectsetuid_p(ThreadContext context, IRubyObject recv, IRubyObject filename) static IRubyObjectsize(ThreadContext context, IRubyObject recv, IRubyObject filename) static IRubyObjectsize_p(ThreadContext context, IRubyObject recv, IRubyObject filename) static IRubyObjectsocket_p(IRubyObject recv, IRubyObject filename) Deprecated.static IRubyObjectsocket_p(ThreadContext context, IRubyObject recv, IRubyObject filename) static IRubyObjectsticky_p(IRubyObject recv, IRubyObject filename) Deprecated.static IRubyObjectsticky_p(ThreadContext context, IRubyObject recv, IRubyObject filename) static RubyBooleansymlink_p(IRubyObject recv, IRubyObject filename) Deprecated.static RubyBooleansymlink_p(ThreadContext context, IRubyObject recv, IRubyObject filename) static IRubyObjectworldReadable(ThreadContext context, IRubyObject recv, IRubyObject filename) static IRubyObjectworldWritable(ThreadContext context, IRubyObject recv, IRubyObject filename) static RubyBooleanwritable_p(IRubyObject recv, IRubyObject filename) Deprecated.static RubyBooleanwritable_p(ThreadContext context, IRubyObject recv, IRubyObject filename) static RubyBooleanzero_p(ThreadContext context, IRubyObject recv, IRubyObject filename)
-
Constructor Details
-
FileTestFileMethods
public FileTestFileMethods()
-
-
Method Details
-
blockdev_p
-
blockdev_p
@Deprecated(since="10.0.0.0") public static IRubyObject blockdev_p(IRubyObject recv, IRubyObject filename) Deprecated. -
chardev_p
-
chardev_p
@Deprecated(since="10.0.0.0") public static IRubyObject chardev_p(IRubyObject recv, IRubyObject filename) Deprecated. -
directory_p
public static IRubyObject directory_p(ThreadContext context, IRubyObject recv, IRubyObject filename) -
executable_p
public static IRubyObject executable_p(ThreadContext context, IRubyObject recv, IRubyObject filename) -
executable_p
@Deprecated(since="10.0.0.0") public static IRubyObject executable_p(IRubyObject recv, IRubyObject filename) Deprecated. -
executable_real_p
public static IRubyObject executable_real_p(ThreadContext context, IRubyObject recv, IRubyObject filename) -
executable_real_p
@Deprecated(since="10.0.0.0") public static IRubyObject executable_real_p(IRubyObject recv, IRubyObject filename) Deprecated. -
exist_p
-
file_p
-
grpowned_p
-
grpowned_p
@Deprecated(since="10.0.0.0") public static IRubyObject grpowned_p(IRubyObject recv, IRubyObject filename) Deprecated. -
identical_p
public static IRubyObject identical_p(ThreadContext context, IRubyObject recv, IRubyObject filename1, IRubyObject filename2) -
owned_p
-
owned_p
@Deprecated(since="10.0.0.0") public static IRubyObject owned_p(IRubyObject recv, IRubyObject filename) Deprecated. -
pipe_p
-
pipe_p
@Deprecated(since="10.0.0.0") public static IRubyObject pipe_p(IRubyObject recv, IRubyObject filename) Deprecated. -
readable_p
-
setgid_p
-
setgid_p
@Deprecated(since="10.0.0.0") public static IRubyObject setgid_p(IRubyObject recv, IRubyObject filename) Deprecated. -
setuid_p
-
setuid_p
@Deprecated(since="10.0.0.0") public static IRubyObject setuid_p(IRubyObject recv, IRubyObject filename) Deprecated. -
size
-
size_p
-
socket_p
-
socket_p
@Deprecated(since="10.0.0.0") public static IRubyObject socket_p(IRubyObject recv, IRubyObject filename) Deprecated. -
sticky_p
-
sticky_p
@Deprecated(since="10.0.0.0") public static IRubyObject sticky_p(IRubyObject recv, IRubyObject filename) Deprecated. -
symlink_p
-
symlink_p
@Deprecated(since="10.0.0.0") public static RubyBoolean symlink_p(IRubyObject recv, IRubyObject filename) Deprecated. -
writable_p
-
writable_p
@Deprecated(since="10.0.0.0") public static RubyBoolean writable_p(IRubyObject recv, IRubyObject filename) Deprecated. -
zero_p
-
worldReadable
public static IRubyObject worldReadable(ThreadContext context, IRubyObject recv, IRubyObject filename) -
worldWritable
public static IRubyObject worldWritable(ThreadContext context, IRubyObject recv, IRubyObject filename) -
identical_p
@Deprecated(since="9.4.6.0") public static IRubyObject identical_p(IRubyObject recv, IRubyObject filename1, IRubyObject filename2) Deprecated.
-