java.lang.Object
org.jruby.RubyBasicObject
org.jruby.RubyObject
org.jruby.RubyRandomBase
org.jruby.RubyRandom
- All Implemented Interfaces:
Serializable,Cloneable,Comparable<IRubyObject>,InstanceVariables,InternalVariables,IRubyObject,CoreObjectType
Implementation of the Random class.
- See Also:
-
Nested Class Summary
Nested ClassesNested classes/interfaces inherited from class org.jruby.RubyObject
RubyObject.DataNested classes/interfaces inherited from class org.jruby.RubyBasicObject
RubyBasicObject.Finalizer -
Field Summary
Fields inherited from class org.jruby.RubyRandomBase
randomFields inherited from class org.jruby.RubyObject
IVAR_INSPECTING_OBJECT_ALLOCATOR, OBJECT_ALLOCATOR, REIFYING_OBJECT_ALLOCATORFields inherited from class org.jruby.RubyBasicObject
ALL_F, BASICOBJECT_ALLOCATOR, COMPARE_BY_IDENTITY_F, ERR_INSECURE_SET_INST_VAR, FALSE_F, FL_USHIFT, flags, FROZEN_F, IS_OVERLAID_F, metaClass, NEVER, NIL_F, REFINED_MODULE_F, STAMP_OFFSET, TAINTED_F, UNDEF, USER0_F, USER1_F, USER2_F, USER3_F, USER4_F, USER5_F, USER6_F, USER7_F, USER8_F, USER9_F, USERA_F, VAR_TABLE_OFFSET, varTable, varTableStampFields inherited from interface org.jruby.runtime.builtin.IRubyObject
NULL_ARRAY -
Method Summary
Modifier and TypeMethodDescriptionstatic IRubyObjectbytes(ThreadContext context, IRubyObject recv, IRubyObject arg) static RubyClasscreateRandomClass(ThreadContext context, RubyClass Object) org.jruby.RubyRandom.RandomTypeinitialize_copy(ThreadContext context, IRubyObject orig) Initializes this object as a copy of the original, that is the parameter to this object.static IRubyObjectleft(ThreadContext context, IRubyObject recv) leftObj(ThreadContext context) marshal_dump(ThreadContext context) marshal_load(ThreadContext context, IRubyObject arg) static RubyRandomnewRandom(Ruby runtime, RubyClass randomClass, IRubyObject seed) Deprecated.static RubyRandomnewRandom(ThreadContext context, RubyClass randomClass, IRubyObject seed) static IRubyObjectnewSeed(ThreadContext context, IRubyObject recv) op_equal(ThreadContext context, IRubyObject obj) rb_obj_equal Will by default use identity equality to compare objects.static IRubyObjectrand(ThreadContext context, IRubyObject recv, IRubyObject[] args) Deprecated.static IRubyObjectrandDefault(ThreadContext context, IRubyObject recv) static IRubyObjectrandDefault(ThreadContext context, IRubyObject recv, IRubyObject arg) randObj(ThreadContext context, IRubyObject[] args) Deprecated.static RubyBignumrandomSeed(Ruby runtime) static BigIntegerrandomSeedBigInteger(Random random) static IRubyObjectrbDefault(ThreadContext context, IRubyObject self) static IRubyObjectseed(ThreadContext context, IRubyObject self) static IRubyObjectsrand(ThreadContext context, IRubyObject recv) static IRubyObjectsrand(ThreadContext context, IRubyObject recv, IRubyObject seed) static IRubyObjectsrandCommon(ThreadContext context, IRubyObject recv) static IRubyObjectsrandCommon(ThreadContext context, IRubyObject recv, IRubyObject newSeed) static IRubyObjectstate(ThreadContext context, IRubyObject recv) stateObj(ThreadContext context) static IRubyObjecturandom(ThreadContext context, IRubyObject recv, IRubyObject num) Methods inherited from class org.jruby.RubyRandomBase
bytes, bytesCommon, initialize, rand, rand, randFloat, randFloat, randLimited, randLimited, randLimitedFixnumInner, randomLongLimited, randomReal, seedMethods inherited from class org.jruby.RubyObject
attachToObjectSpace, callInit, callInit, callInit, callInit, callInit, callInit, callInit, callInit, callInit, callInit, convertToType, dig, dig1, dig2, eqlInternal, equalInternal, equals, finishObjectClass, getNativeClassIndex, hashCode, inspect, op_eqq, puts, specificEval, toRubyString, toStringMethods inherited from class org.jruby.RubyBasicObject
__id__, addFinalizer, addFinalizer, anyToString, asJavaString, asString, callMethod, callMethod, callMethod, callMethod, callMethod, callMethod, callMethod, callMethod, callMethod, callSuper, checkArrayType, checkCallMethod, checkCallMethod, checkFrozen, checkStringType, cloneSetup, compareTo, convertToArray, convertToFloat, convertToHash, convertToInteger, convertToInteger, convertToInteger, convertToString, copyInstanceVariablesInto, copySpecialInstanceVariables, dataGetStruct, dataGetStructChecked, dataWrapStruct, decode, display, dup, dupFinalizer, dupSetup, ensureInstanceVariablesSettable, eql, eql_p, eql_p, equal_p, evalUnder, extend, fastGetInstanceVariable, fastGetInternalVariable, fastHasInstanceVariable, fastHasInternalVariable, fastSetInstanceVariable, fastSetInternalVariable, finishBasicObjectClass, forEachInstanceVariable, forEachInstanceVariableName, freeze, frozen_p, getCurrentContext, getFFIHandle, getFlag, getInstanceEvalClass, getInstanceEvalClass, getInstanceVariable, getInstanceVariableList, getInstanceVariableNameList, getInstanceVariables, getInternalVariable, getInternalVariables, getJavaClass, getMarshalVariableList, getMetaClass, getMetaClass, getNativeHandle, getNativeTypeIndex, getObjectId, getRuntime, getSingletonClass, getSingletonClassClone, getSingletonClassCloneAndAttach, getSingletonClassCloneAndAttach, getType, getVariable, getVariableCount, getVariableList, getVariableNameList, hash, hash, hashyInspect, hasInstanceVariable, hasInstanceVariables, hasInternalVariable, hasVariables, id, infectBy, initialize, initialize_copy, inspect, inspect, inspectHashCode, instance_eval, instance_eval, instance_eval, instance_eval, instance_eval, instance_exec, instance_of_p, instance_variable_defined_p, instance_variable_get, instance_variable_set, instance_variables, isBuiltin, isClass, isFalse, isFrozen, isImmediate, isModule, isNil, isSpecialConst, isSpecialObject, isTaint, isTrue, isUntrusted, kind_of_p, makeMetaClass, makeMetaClass, makeMetaClassBootstrap, method, method, method, method_missing, methods, methods, nil_p, nonFixnumHashCode, nonFixnumHashCode, OBJ_INIT_COPY, objInitCopy, op_cmp, op_match, op_not, op_not_equal, op_not_match, private_methods, protected_methods, public_methods, rbClone, rbClone, rbInspect, remove_instance_variable, removeFinalizers, removeInstanceVariable, removeInternalVariable, respond_to_p, respond_to_p, respondsTo, respondsToMissing, respondsToMissing, send, send, send, send, send, setFFIHandle, setFlag, setFrozen, setInstanceVariable, setInternalVariable, setMetaClass, setNativeHandle, setTaint, setUntrusted, setVariable, singleton_method, singleton_method, singleton_method_added, singleton_method_removed, singleton_method_undefined, singleton_methods, singletonClass, specificEval, specificEval, specificEval, specificEval, syncVariables, syncVariables, taint, taint, tainted_p, testFrozen, testFrozen, to_a, to_a, to_s, to_s, toJava, trust, type, untaint, untrust, untrusted_p, validateInstanceVariable, validateInstanceVariable, validateInstanceVariable, variableTableContains, variableTableFastContains, variableTableFastFetch, variableTableFastStore, variableTableFetch, variableTableRemove, variableTableStore, variableTableSync, yieldUnder, yieldUnderMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface org.jruby.runtime.builtin.IRubyObject
checkStringType19, dup, marshalLiveVariables
-
Method Details
-
randomSeedBigInteger
-
randomSeed
-
createRandomClass
-
newRandom
@Deprecated(since="10.0.0.0") public static RubyRandom newRandom(Ruby runtime, RubyClass randomClass, IRubyObject seed) Deprecated. -
newRandom
-
getRandomType
public org.jruby.RubyRandom.RandomType getRandomType() -
seed
-
initialize_copy
Description copied from class:RubyBasicObjectInitializes this object as a copy of the original, that is the parameter to this object. Will make sure that the argument actually has the same real class as this object. It shouldn't be possible to initialize an object with something totally different.- Overrides:
initialize_copyin classRubyBasicObject- Parameters:
context- the thread contextorig- the original- Returns:
- a copy unless the same thing
-
randDefault
-
randDefault
-
rbDefault
-
srand
-
srand
-
srandCommon
-
srandCommon
-
op_equal
Description copied from class:RubyBasicObjectrb_obj_equal Will by default use identity equality to compare objects. This follows the Ruby semantics. The name of this method doesn't follow the convention because hierarchy problems- Specified by:
op_equalin interfaceIRubyObject- Overrides:
op_equalin classRubyBasicObject
-
stateObj
-
leftObj
-
state
-
left
-
marshal_dump
-
marshal_load
-
bytes
-
newSeed
-
urandom
-
rand
@Deprecated(since="9.3.0.0") public static IRubyObject rand(ThreadContext context, IRubyObject recv, IRubyObject[] args) Deprecated. -
randObj
Deprecated.
-