-
Optional Element Summary
Optional Elements
Any alias or aliases for this method.
Argument types to coerce to before calling
boolean
boolean
Whether automatic arity-checking should be added to the Ruby binding for this
method.
boolean
Whether this method expects to have a call frame allocated for it.
A list of classes that implement an abstract JRubyMethod, for backtrace purposes.
boolean
Whether this method may recieve keyword arguments.
boolean
Whether this method should be defined on the metaclass.
boolean
Whether this method should be a module function, defined on metaclass and private on class.
The name or names of this method in Ruby-land.
boolean
Whether this method should show up as defined in response to respond_to? calls
boolean
Whether to use a frame slot for backtrace information
int
The number of optional arguments.
What, if anything, method reads from caller's frame
int
The number of required arguments.
boolean
Whether this method has a "rest" argument.
boolean
The visibility of this method.
What, if anything, method writes to caller's frame
-
Element Details
-
name
The name or names of this method in Ruby-land.
- Default:
{}
-
required
int required
The number of required arguments.
- Default:
0
-
optional
int optional
The number of optional arguments.
- Default:
0
-
rest
boolean rest
Whether this method has a "rest" argument.
- Default:
false
-
alias
Any alias or aliases for this method.
- Default:
{}
-
-
module
boolean module
Whether this method should be a module function, defined on metaclass and private on class.
- Default:
false
-
keywords
boolean keywords
Whether this method may recieve keyword arguments. Methods may directly process the keywords
or decide to pass them on to a subcall. This will determine whether ThreadContext#callInfo
will get reset before the call begins or not. If keywords is true then it is the methods
job to reset or not reset callInfo.
- Default:
false
-
frame
boolean frame
Whether this method expects to have a call frame allocated for it.
- Default:
false
-
visibility
The visibility of this method.
- Default:
DEFAULT
-
reads
What, if anything, method reads from caller's frame
- Default:
{}
-
writes
What, if anything, method writes to caller's frame
- Default:
{}
-
argTypes
Argument types to coerce to before calling
- Default:
{}
-
omit
boolean omit
Whether to use a frame slot for backtrace information
- Default:
false
-
notImplemented
boolean notImplemented
Whether this method should show up as defined in response to respond_to? calls
- Default:
false
-
checkArity
boolean checkArity
Whether automatic arity-checking should be added to the Ruby binding for this
method. Users can opt-out and do their own arity-checking in the method body.
- Default:
true
-
implementers
A list of classes that implement an abstract JRubyMethod, for backtrace purposes.
- Default:
{}
-
scope
Deprecated.
- Default:
false
-
backtrace
Deprecated.
- Default:
false