Uses of Enum Class
org.jruby.anno.FrameField
Packages that use FrameField
-
Uses of FrameField in org.jruby
Fields in org.jruby with type parameters of type FrameFieldModifier and TypeFieldDescriptionMap<Set<FrameField>, List<String>> RubyModule.MethodClumper.readGroupsMap<Set<FrameField>, List<String>> RubyModule.MethodClumper.writeGroups -
Uses of FrameField in org.jruby.anno
Methods in org.jruby.anno that return FrameFieldModifier and TypeMethodDescriptionstatic FrameFieldReturns the enum constant of this class with the specified name.static FrameField[]FrameField.values()Returns an array containing the constants of this enum class, in the order they are declared.Methods in org.jruby.anno that return types with arguments of type FrameFieldMethods in org.jruby.anno with parameters of type FrameFieldMethod parameters in org.jruby.anno with type arguments of type FrameFieldModifier and TypeMethodDescriptionstatic voidAnnotationHelper.groupFrameFields(Map<Set<FrameField>, List<String>> readGroups, Map<Set<FrameField>, List<String>> writeGroups, JRubyMethod anno, String simpleName) static voidAnnotationHelper.populateMethodIndex(Map<Set<FrameField>, List<String>> accessGroups, BiConsumer<Integer, String> action) -
Uses of FrameField in org.jruby.runtime
Fields in org.jruby.runtime with type parameters of type FrameFieldModifier and TypeFieldDescriptionstatic final Map<String, Set<FrameField>> MethodIndex.METHOD_FRAME_READSstatic final Map<String, Set<FrameField>> MethodIndex.METHOD_FRAME_WRITESMethods in org.jruby.runtime with parameters of type FrameFieldModifier and TypeMethodDescriptionstatic voidMethodIndex.addMethodReadFields(String name, FrameField... reads) static voidMethodIndex.addMethodWriteFields(String name, FrameField... write)