Uses of Class
org.jruby.RubyArrayNative
Packages that use RubyArrayNative
-
Uses of RubyArrayNative in org.jruby
Methods in org.jruby that return RubyArrayNativeModifier and TypeMethodDescriptionRubyArrayNative.aryDup()rb_ary_dupprotected RubyArrayNativeprotected RubyArrayNative<?> RubyArrayNative.makeShared()rb_ary_make_sharedstatic RubyArrayNative<?> static RubyArrayNative<?> RubyArrayNative.newArray(Ruby runtime, Collection<? extends IRubyObject> collection) static RubyArrayNative<?> RubyArrayNative.newArray(Ruby runtime, List<? extends IRubyObject> list) static RubyArrayNative<?> RubyArrayNative.newArray(Ruby runtime, IRubyObject obj) static RubyArrayNative<?> RubyArrayNative.newArray(Ruby runtime, IRubyObject[] args) rb_ary_new4, rb_ary_new3static RubyArrayNative<?> RubyArrayNative.newArray(Ruby runtime, IRubyObject car, IRubyObject cdr) rb_assoc_newstatic RubyArrayNative<?> RubyArrayNative.newArray(Ruby runtime, IRubyObject first, IRubyObject second, IRubyObject third) static RubyArrayNative<?> RubyArrayNative.newArray(Ruby runtime, IRubyObject first, IRubyObject second, IRubyObject third, IRubyObject fourth) static final RubyArrayNative<?> RubyArrayNative.newArray(ThreadContext context) rb_ary_newstatic final RubyArrayNative<?> RubyArrayNative.newArray(ThreadContext context, int len) static final RubyArrayNative<?> RubyArrayNative.newArrayLight(Ruby runtime) rb_ary_newstatic RubyArrayNative<?> RubyArrayNative.newArrayLight(RubyClass arrayClass, IRubyObject obj) static RubyArrayNative<?> RubyArrayNative.newArrayLight(RubyClass arrayClass, IRubyObject car, IRubyObject cdr) static final RubyArrayNative<?> RubyArrayNative.newArrayLight(Ruby runtime, int len) static RubyArrayNative<?> RubyArrayNative.newArrayLight(Ruby runtime, IRubyObject obj) static RubyArrayNative<?> RubyArrayNative.newArrayLight(Ruby runtime, IRubyObject... objs) static RubyArrayNative<?> RubyArrayNative.newArrayLight(Ruby runtime, IRubyObject car, IRubyObject cdr) static RubyArrayNativeRubyArrayNative.newArrayMayCopy(Ruby runtime, IRubyObject... args) static RubyArrayNativeRubyArrayNative.newArrayMayCopy(Ruby runtime, IRubyObject[] args, int start) static RubyArrayNativeRubyArrayNative.newArrayMayCopy(Ruby runtime, IRubyObject[] args, int start, int length) Construct a new RubyArray given the specified range of elements in the source array.static RubyArrayNativeRubyArrayNative.newArrayNoCopy(Ruby runtime, IRubyObject... args) static RubyArrayNativeRubyArrayNative.newArrayNoCopy(Ruby runtime, IRubyObject[] args, int begin) static RubyArrayNativeRubyArrayNative.newArrayNoCopy(Ruby runtime, IRubyObject[] args, int begin, int length) static RubyArrayNativeRubyArrayNative.newArrayNoCopyLight(Ruby runtime, IRubyObject[] args) static RubyArrayNative<?> RubyArrayNative.newEmptyArray(Ruby runtime) static RubyArrayNative<?> RubyArrayNative.newEmptyArray(Ruby runtime, RubyClass klass) static RubyArrayNative<?> RubyArrayNative.newSharedArray(RubyClass arrayClass, IRubyObject[] shared) Methods in org.jruby with parameters of type RubyArrayNativeModifier and TypeMethodDescriptionprotected booleanRubyArrayNative.flatten(ThreadContext context, int level, RubyArrayNative result) -
Uses of RubyArrayNative in org.jruby.api
Methods in org.jruby.api that return RubyArrayNativeModifier and TypeMethodDescriptionstatic RubyArrayNative<?> Create.allocNativeArray(ThreadContext context, int length) static RubyArrayNative<?> Create.allocNativeArray(ThreadContext context, long length) -
Uses of RubyArrayNative in org.jruby.specialized
Subclasses of RubyArrayNative in org.jruby.specializedModifier and TypeClassDescriptionclassOne object version of RubyArraySpecialized.classThis is the base class for all specialized RubyArray.classTwo object version of RubyArraySpecialized.Methods in org.jruby.specialized that return RubyArrayNativeModifier and TypeMethodDescriptionRubyArrayOneObject.aryDup()RubyArrayTwoObject.aryDup()protected RubyArrayNative<?> protected RubyArrayNative<?> protected RubyArrayNative<?> RubyArrayOneObject.makeShared()protected RubyArrayNative<?> RubyArrayTwoObject.makeShared() -
Uses of RubyArrayNative in org.jruby.util.collections
Subclasses of RubyArrayNative in org.jruby.util.collectionsModifier and TypeClassDescriptionclassAn RubyArray that maintains an O(1) Set for fast include? operations.