Uses of Class
org.jruby.RubyHashLinkedBuckets
Packages that use RubyHashLinkedBuckets
-
Uses of RubyHashLinkedBuckets in org.jruby
Subclasses of RubyHashLinkedBuckets in org.jrubyModifier and TypeClassDescriptionstatic classObligate string-keyed and string-valued hash, used for ENV.static classA Pseudo-hash whose keys and values are required to be Strings.Methods in org.jruby that return RubyHashLinkedBucketsModifier and TypeMethodDescriptionRubyHashLinkedBuckets.convertToHash()RubyHashLinkedBuckets.delete_ifInternal(ThreadContext context, Block block) rb_hash_delete_ifRubyHashLinkedBuckets.dupFast(ThreadContext context) A lightweight dup for internal use that does not dispatch to initialize_copy nor rehash the keys.RubyHashLinkedBuckets.each_keyCommon(ThreadContext context, Block block) rb_hash_each_keyRubyHashLinkedBuckets.each_pairCommon(ThreadContext context, Block block) rb_hash_each_pairRubyHashLinkedBuckets.each_valueCommon(ThreadContext context, Block block) rb_hash_each_valueRubyHashLinkedBuckets.eachCommon(ThreadContext context, Block block) rb_hash_eachRubyHashLinkedBuckets.merge_bang(ThreadContext context, IRubyObject[] others, Block block) rb_hash_updatestatic RubyHashLinkedBucketsstatic RubyHashLinkedBucketsstatic RubyHashLinkedBucketsstatic RubyHashLinkedBucketsRubyHashLinkedBuckets.newLBHash(Ruby runtime, IRubyObject defaultValue) static RubyHashLinkedBucketsRubyHashLinkedBuckets.newLBHash(Ruby runtime, IRubyObject defaultValue, int buckets) RubyHashLinkedBuckets.rejectInternal(ThreadContext context, Block block) rb_hash_rejectRubyHashLinkedBuckets.withRuby2Keywords(boolean ruby2Keywords) Methods in org.jruby with parameters of type RubyHashLinkedBucketsModifier and TypeMethodDescriptionstatic voidRubyHashLinkedBuckets.marshalTo(ThreadContext context, RubyOutputStream out, RubyHashLinkedBuckets hash, MarshalDumper output)