Specifies that Ruby's local variables have faithful behavior to its semantics.
Local variables do not survive over an evaluation. All local variables
will vanish after every evaluation.
Specifies that a sharing variable works for BSF JRuby Engine.
Variable names in Java are mapped to global variables in Ruby when it is
shared through org.apache.bsf.BSFDeclaredBean.
Returns the enum constant of this class with the specified name.
The string must match exactly an identifier used to declare an
enum constant in this class. (Extraneous whitespace characters are
not permitted.)
Parameters:
name - the name of the enum constant to be returned.