Uses of Package
org.jruby.ext.ffi
Packages that use org.jruby.ext.ffi
-
Classes in org.jruby.ext.ffi used by org.jruby
-
Classes in org.jruby.ext.ffi used by org.jruby.ext.ffiClassDescriptionA native function invokerA abstract memory object that defines operations common to both pointers and memory buffersDefines a C callback's parameters and return type.A factory that can create a FFI ProviderAn implementation of MemoryIO that throws an exception on any access.Abstracted memory operations.Native typesAn implementation of MemoryIO that throws an exception on any access.C memory pointer operations.Defines the memory layout for a native structure.A struct member.
-
Classes in org.jruby.ext.ffi used by org.jruby.ext.ffi.jffiClassDescriptionA native function invokerA abstract memory object that defines operations common to both pointers and memory buffersDefines a C callback's parameters and return type.A factory that can create a FFI ProviderAn implementation of MemoryIO that throws an exception on any access.A type which represents a conversion to/from a native type.Abstracted memory operations.Native typesC memory pointer operations.