java.lang.Object
org.jruby.RubyBasicObject
org.jruby.RubyObject
org.jruby.RubyIO
org.jruby.ext.socket.RubyBasicSocket
org.jruby.ext.socket.RubySocket
- All Implemented Interfaces:
Closeable,Flushable,Serializable,AutoCloseable,Cloneable,Comparable<IRubyObject>,InstanceVariables,InternalVariables,IRubyObject,CoreObjectType,IOEncodable
- Direct Known Subclasses:
RubyServerSocket
- See Also:
-
Nested Class Summary
Nested classes/interfaces inherited from class org.jruby.ext.socket.RubyBasicSocket
RubyBasicSocket.LibC, RubyBasicSocket.ReceiveTupleNested classes/interfaces inherited from class org.jruby.RubyIO
RubyIO.IOEvent, RubyIO.RubyIOTimeoutError, RubyIO.Sysopen, RubyIO.TimeoutErrorNested classes/interfaces inherited from class org.jruby.RubyObject
RubyObject.DataNested classes/interfaces inherited from class org.jruby.RubyBasicObject
RubyBasicObject.FinalizerNested classes/interfaces inherited from interface org.jruby.util.io.IOEncodable
IOEncodable.ConvConfig -
Field Summary
FieldsModifier and TypeFieldDescriptionprotected jnr.constants.platform.AddressFamilyprotected jnr.netdb.Protocolprotected jnr.constants.platform.ProtocolFamilyprotected jnr.constants.platform.SockFields inherited from class org.jruby.ext.socket.RubyBasicSocket
multicastStateManagerFields inherited from class org.jruby.RubyIO
CLOSED_STREAM_MSG, FD_CLOEXEC, openFile, PARAGRAPH_SEPARATOR, popenSpecialFields inherited from class org.jruby.RubyObject
IVAR_INSPECTING_OBJECT_ALLOCATOR, OBJECT_ALLOCATOR, REIFYING_OBJECT_ALLOCATORFields inherited from class org.jruby.RubyBasicObject
ALL_F, BASICOBJECT_ALLOCATOR, COMPARE_BY_IDENTITY_F, ERR_INSECURE_SET_INST_VAR, FALSE_F, FL_USHIFT, flags, FROZEN_F, IS_OVERLAID_F, metaClass, NEVER, NIL_F, REFINED_MODULE_F, STAMP_OFFSET, TAINTED_F, UNDEF, USER0_F, USER1_F, USER2_F, USER3_F, USER4_F, USER5_F, USER6_F, USER7_F, USER8_F, USER9_F, USERA_F, VAR_TABLE_OFFSET, varTable, varTableStampFields inherited from interface org.jruby.runtime.builtin.IRubyObject
NULL_ARRAY -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionaccept(ThreadContext context) accept_nonblock(ThreadContext context, IRubyObject[] args) protected IRubyObjectaddrFor(ThreadContext context, InetSocketAddress addr, boolean reverse) bind(ThreadContext context, IRubyObject arg) close(ThreadContext context) Closes all open resources for the IO.closed_p(ThreadContext context) connect(ThreadContext context, IRubyObject arg) connect_nonblock(ThreadContext context, IRubyObject arg) connect_nonblock(ThreadContext context, IRubyObject arg, IRubyObject opts) protected voiddoBind(ThreadContext context, SocketAddress iaddr) protected IRubyObjectdoConnect(ThreadContext context, SocketAddress addr, boolean ex) static IRubyObjectfor_fd(ThreadContext context, IRubyObject socketClass, IRubyObject _fd) static IRubyObjectgetaddrinfo(ThreadContext context, IRubyObject recv, IRubyObject[] args) static IRubyObjectgethostbyaddr(ThreadContext context, IRubyObject recv, IRubyObject[] args) static IRubyObjectgethostbyname(ThreadContext context, IRubyObject recv, IRubyObject hostname) static IRubyObjectgethostname(ThreadContext context, IRubyObject recv) static IRubyObjectgetifaddrs(ThreadContext context, IRubyObject recv) static IRubyObjectgetnameinfo(ThreadContext context, IRubyObject recv, IRubyObject[] args) static IRubyObjectgetservbyname(ThreadContext context, IRubyObject recv, IRubyObject[] args) protected SocketAddressprotected ChannelFDinitChannelFD(Ruby runtime) protected voidinitFromServer(Ruby runtime, RubySocket serverSocket, SocketChannel socketChannel) initialize(ThreadContext context, IRubyObject domain, IRubyObject type) initialize(ThreadContext context, IRubyObject domain, IRubyObject type, IRubyObject protocol) static IRubyObjectip_address_list(ThreadContext context, IRubyObject self) listen(ThreadContext context, IRubyObject backlog) static IRubyObjectpack_sockaddr_in(ThreadContext context, IRubyObject recv, IRubyObject port, IRubyObject host) static IRubyObjectpack_sockaddr_un(ThreadContext context, IRubyObject recv, IRubyObject filename) recvfrom(ThreadContext context, IRubyObject _length) recvfrom(ThreadContext context, IRubyObject _length, IRubyObject _flags) Overrides IPSocket#recvfromrecvfrom_nonblock(ThreadContext context, IRubyObject[] args) static RuntimeExceptionDeprecated.static IRubyObjectsocketpair(ThreadContext context, IRubyObject recv, IRubyObject domain, IRubyObject type) static IRubyObjectsocketpair(ThreadContext context, IRubyObject recv, IRubyObject domain, IRubyObject type, IRubyObject protocol) static IRubyObjecttcp_fast_fallback(ThreadContext context, IRubyObject self) static IRubyObjecttcp_fast_fallback_set(ThreadContext context, IRubyObject self, IRubyObject value) static IRubyObjectunpack_sockaddr_in(ThreadContext context, IRubyObject recv, IRubyObject addr) static IRubyObjectunpack_sockaddr_un(ThreadContext context, IRubyObject recv, IRubyObject addr) Methods inherited from class org.jruby.ext.socket.RubyBasicSocket
asBoolean, bindContextMessage, bindContextMessage, close_read, close_write, do_not_reverse_lookup, do_not_reverse_lookup, do_not_reverse_lookup, doNotReverseLookup, doRead, doReadNonblock, getInetRemoteSocket, getInetRemoteSocket, getInetSocketAddress, getpeereid, getpeername, getpeername, getRemoteSocket, getRemoteSocket, getsockname, getsockname, getSocknameCommon, getsockopt, getsockopt, getUnixRemoteSocket, getUnixRemoteSocket, getUnixSocketAddress, initSocket, local_address, newChannelFD, read_nonblock, read_nonblock, read_nonblock, read_nonblock, recv, recv, recv, recv_nonblock, recvmsg, recvmsg_nonblock, remote_address, send, send, sendmsg, sendmsg_nonblock, set_do_not_reverse_lookup, set_do_not_reverse_lookup, set_do_not_reverse_lookup, setsockopt, setsockopt, setsockopt, shutdownMethods inherited from class org.jruby.RubyIO
addBlockingThread, advise, autoclose, autoclose_set, binmode, binmode, binread, binwrite, bytes, chars, checkExecEnv, checkExecOptions, checkLength, checkPopenOptions, checkSpawnOptions, cloexecOpen, close, close_on_exec_p, close_on_exec_set, codepoints, convertToIO, copy_stream, copy_stream, copy_stream, createIOClass, doRead, doReadNonblock, doReadNonblock, doReadNonblock, doReadNonblock, doWriteNonblock, each, each, each, each, each, each_byte, each_byteInternal, each_char, each_charInternal, each_codepoint, each_line, each_line, each_line, each_line, each_line, ensureYieldClose, ensureYieldClosePipes, eof_p, external_encoding, failIfDirectory, fcntl, fcntl, fileno, flush, flush, flushRaw, for_fd, foreach, fsync, getBlocking, getBOM, getbyte, getByte, getc, getc, getChannel, getEcflags, getEcopts, getEnc, getEnc2, getInputEncoding, getInStream, getIOModes, getIOModesIntFromString, getline, getline, getline, getline, getline, getline, getNativeClassIndex, getOpenFile, getOpenFileChecked, getOpenFileInitialized, getOutStream, getPath, getReadEncoding, gets, gets, gets, gets, getSync, GetWriteIO, initialize, initialize, initialize, initialize_copy, inspect, internal_encoding, ioClose, ioctl, ioOpen, ioOpen, ioStaticWrite, isAutoclose, isClosed, lineno, lineno_set, lines, MakeOpenFile, newInstance, newIO, newIOOptions, newIOOptions, newIOOptions, newIOOptions, newIOOptions, newModeFlags, newModeFlags, newModeFlags, obliterateProcess, op_append, op_binmode, open, parseIOOptions, path, pid, pipe, pipe, pipe, pipe, pipe, pipe, popen, popen3, popen4, popenSpecial, pos, pos_set, pread, pread, prepStdio, prepStdio, print, print, print, print, print, print, print0, print1, print2, print3, printf, printf, putc, putc, puts, puts, puts, puts, puts, puts, puts0, puts1, puts2, puts3, pwrite, rbIoClose, read, read, read, read, read, read, read, read, readbyte, readchar, readchar, readline, readline, readline, readline, readline, readlines, readlines, readlines, readlines, readlines, readlines, readpartial, readpartial, readpartial, removeBlockingThread, reopen, reopenIO, rewind, seek, seek, seek, select, select_static, set_encoding, set_encoding, set_encoding, set_encoding_by_bom, setAscii8bitBinmode, setAutoclose, setBlocking, setBOM, setEcflags, setEcopts, setEnc, setEnc2, setEncoding, setPath, setSync, stat, sync, sync_set, sync_set, sysopen, sysopen, sysopen, sysread, sysread, sysread, sysseek, syswrite, to_io, toJava, toString, tryConvert, tty_p, ungetbyte, ungetc, updateIOOptionsFromOptions, wait, wait, wait_readable, wait_readable, wait_writable, wait_writable, write, write, write, write, write, write, write, write, write, write, write, write, write, write, write, write, write_nonblock, write_nonblock, write_nonblock, write2, write3, writeStatic, writev, writev, writev, writev, writevMethods inherited from class org.jruby.RubyObject
attachToObjectSpace, callInit, callInit, callInit, callInit, callInit, callInit, callInit, callInit, callInit, callInit, convertToType, dig, dig1, dig2, eqlInternal, equalInternal, equals, finishObjectClass, hashCode, inspect, op_eqq, puts, specificEval, toRubyStringMethods inherited from class org.jruby.RubyBasicObject
__id__, addFinalizer, addFinalizer, anyToString, asJavaString, asString, callMethod, callMethod, callMethod, callMethod, callMethod, callMethod, callMethod, callMethod, callMethod, callSuper, checkArrayType, checkCallMethod, checkCallMethod, checkFrozen, checkStringType, cloneSetup, compareTo, convertToArray, convertToFloat, convertToHash, convertToInteger, convertToInteger, convertToInteger, convertToString, copyInstanceVariablesInto, copySpecialInstanceVariables, dataGetStruct, dataGetStructChecked, dataWrapStruct, decode, display, dup, dupFinalizer, dupSetup, ensureInstanceVariablesSettable, eql, eql_p, eql_p, equal_p, evalUnder, extend, fastGetInstanceVariable, fastGetInternalVariable, fastHasInstanceVariable, fastHasInternalVariable, fastSetInstanceVariable, fastSetInternalVariable, finishBasicObjectClass, forEachInstanceVariable, forEachInstanceVariableName, freeze, frozen_p, getCurrentContext, getFFIHandle, getFlag, getInstanceEvalClass, getInstanceEvalClass, getInstanceVariable, getInstanceVariableList, getInstanceVariableNameList, getInstanceVariables, getInternalVariable, getInternalVariables, getJavaClass, getMarshalVariableList, getMetaClass, getMetaClass, getNativeHandle, getNativeTypeIndex, getObjectId, getRuntime, getSingletonClass, getSingletonClassClone, getSingletonClassCloneAndAttach, getSingletonClassCloneAndAttach, getType, getVariable, getVariableCount, getVariableList, getVariableNameList, hash, hash, hashyInspect, hasInstanceVariable, hasInstanceVariables, hasInternalVariable, hasVariables, id, infectBy, initialize, initialize_copy, inspect, inspectHashCode, instance_eval, instance_eval, instance_eval, instance_eval, instance_eval, instance_exec, instance_of_p, instance_variable_defined_p, instance_variable_get, instance_variable_set, instance_variables, isBuiltin, isClass, isFalse, isFrozen, isImmediate, isModule, isNil, isSpecialConst, isSpecialObject, isTaint, isTrue, isUntrusted, kind_of_p, makeMetaClass, makeMetaClass, makeMetaClassBootstrap, method, method, method, method_missing, methods, methods, nil_p, nonFixnumHashCode, nonFixnumHashCode, OBJ_INIT_COPY, objInitCopy, op_cmp, op_equal, op_match, op_not, op_not_equal, op_not_match, private_methods, protected_methods, public_methods, rbClone, rbClone, rbInspect, remove_instance_variable, removeFinalizers, removeInstanceVariable, removeInternalVariable, respond_to_p, respond_to_p, respondsTo, respondsToMissing, respondsToMissing, send, send, send, send, send, setFFIHandle, setFlag, setFrozen, setInstanceVariable, setInternalVariable, setMetaClass, setNativeHandle, setTaint, setUntrusted, setVariable, singleton_method, singleton_method, singleton_method_added, singleton_method_removed, singleton_method_undefined, singleton_methods, singletonClass, specificEval, specificEval, specificEval, specificEval, syncVariables, syncVariables, taint, taint, tainted_p, testFrozen, testFrozen, to_a, to_a, to_s, to_s, trust, type, untaint, untrust, untrusted_p, validateInstanceVariable, validateInstanceVariable, validateInstanceVariable, variableTableContains, variableTableFastContains, variableTableFastFetch, variableTableFastStore, variableTableFetch, variableTableRemove, variableTableStore, variableTableSync, yieldUnder, yieldUnderMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface org.jruby.runtime.builtin.IRubyObject
checkStringType19, dup, marshalLiveVariables
-
Field Details
-
soDomain
protected jnr.constants.platform.AddressFamily soDomain -
soProtocolFamily
protected jnr.constants.platform.ProtocolFamily soProtocolFamily -
soType
protected jnr.constants.platform.Sock soType -
soProtocol
protected jnr.netdb.Protocol soProtocol
-
-
Constructor Details
-
RubySocket
-
-
Method Details
-
for_fd
-
initialize
-
initialize
public IRubyObject initialize(ThreadContext context, IRubyObject domain, IRubyObject type, IRubyObject protocol) -
connect_nonblock
-
connect_nonblock
-
connect
-
bind
-
recvfrom
-
recvfrom
Overrides IPSocket#recvfrom -
recvfrom_nonblock
-
listen
-
accept
-
accept_nonblock
-
gethostname
-
getifaddrs
-
gethostbyaddr
public static IRubyObject gethostbyaddr(ThreadContext context, IRubyObject recv, IRubyObject[] args) -
getservbyname
public static IRubyObject getservbyname(ThreadContext context, IRubyObject recv, IRubyObject[] args) -
pack_sockaddr_in
public static IRubyObject pack_sockaddr_in(ThreadContext context, IRubyObject recv, IRubyObject port, IRubyObject host) -
unpack_sockaddr_in
public static IRubyObject unpack_sockaddr_in(ThreadContext context, IRubyObject recv, IRubyObject addr) -
pack_sockaddr_un
public static IRubyObject pack_sockaddr_un(ThreadContext context, IRubyObject recv, IRubyObject filename) -
unpack_sockaddr_un
public static IRubyObject unpack_sockaddr_un(ThreadContext context, IRubyObject recv, IRubyObject addr) -
gethostbyname
public static IRubyObject gethostbyname(ThreadContext context, IRubyObject recv, IRubyObject hostname) -
getaddrinfo
-
getnameinfo
-
ip_address_list
-
socketpair
public static IRubyObject socketpair(ThreadContext context, IRubyObject recv, IRubyObject domain, IRubyObject type, IRubyObject protocol) -
socketpair
public static IRubyObject socketpair(ThreadContext context, IRubyObject recv, IRubyObject domain, IRubyObject type) -
initFromServer
-
initChannelFD
-
doConnect
-
doBind
-
addrFor
- Overrides:
addrForin classRubyBasicSocket
-
close
Description copied from class:RubyIOCloses all open resources for the IO. It also removes it from our magical all open file descriptor pool.
-
tcp_fast_fallback
-
tcp_fast_fallback_set
public static IRubyObject tcp_fast_fallback_set(ThreadContext context, IRubyObject self, IRubyObject value) -
closed_p
-
getSocketAddress
- Overrides:
getSocketAddressin classRubyBasicSocket
-
sockerr
Deprecated.
-