java.lang.Object
org.jruby.RubyBasicObject
org.jruby.RubyObject
org.jruby.ext.zlib.RubyGzipFile
org.jruby.ext.zlib.JZlibRubyGzipReader
- All Implemented Interfaces:
Serializable,Cloneable,Comparable<IRubyObject>,InstanceVariables,InternalVariables,IRubyObject,CoreObjectType,IOEncodable
- See Also:
-
Nested Class Summary
Nested ClassesNested classes/interfaces inherited from class org.jruby.ext.zlib.RubyGzipFile
RubyGzipFile.CRCError, RubyGzipFile.LengthError, RubyGzipFile.NoFooterNested classes/interfaces inherited from class org.jruby.RubyObject
RubyObject.DataNested classes/interfaces inherited from class org.jruby.RubyBasicObject
RubyBasicObject.FinalizerNested classes/interfaces inherited from interface org.jruby.util.io.IOEncodable
IOEncodable.ConvConfig -
Field Summary
Fields inherited from class org.jruby.ext.zlib.RubyGzipFile
closed, ec, ecflags, ecopts, enc, enc2, finished, hasBOM, level, mtime, nullFreeComment, nullFreeOrigName, osCode, readTranscoder, realIo, sync, writeTranscoderFields inherited from class org.jruby.RubyObject
IVAR_INSPECTING_OBJECT_ALLOCATOR, OBJECT_ALLOCATOR, REIFYING_OBJECT_ALLOCATORFields inherited from class org.jruby.RubyBasicObject
ALL_F, BASICOBJECT_ALLOCATOR, COMPARE_BY_IDENTITY_F, ERR_INSECURE_SET_INST_VAR, FALSE_F, FL_USHIFT, flags, FROZEN_F, IS_OVERLAID_F, metaClass, NEVER, NIL_F, REFINED_MODULE_F, STAMP_OFFSET, TAINTED_F, UNDEF, USER0_F, USER1_F, USER2_F, USER3_F, USER4_F, USER5_F, USER6_F, USER7_F, USER8_F, USER9_F, USERA_F, VAR_TABLE_OFFSET, varTable, varTableStampFields inherited from interface org.jruby.runtime.builtin.IRubyObject
NULL_ARRAY -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionclose(ThreadContext context) comment(ThreadContext context) crc(ThreadContext context) each(ThreadContext context, IRubyObject[] args, Block block) each_byte(ThreadContext context, Block block) each_char(ThreadContext context, Block block) each_line(ThreadContext context, IRubyObject[] args, Block block) eof()Deprecated.eof(ThreadContext context) eof_p()Deprecated.eof_p(ThreadContext context) getbyte()Deprecated.getbyte(ThreadContext context) getc()Deprecated.getc(ThreadContext context) gets(ThreadContext context, IRubyObject[] args) initialize(ThreadContext context, IRubyObject stream) initialize(ThreadContext context, IRubyObject[] args) lineno()Deprecated.lineno(ThreadContext context) static JZlibRubyGzipReadernewInstance(IRubyObject recv, IRubyObject[] args) Deprecated.static JZlibRubyGzipReadernewInstance(ThreadContext context, RubyClass klass, IRubyObject[] args) static IRubyObjectnewInstance(ThreadContext context, IRubyObject recv, IRubyObject[] args, Block block) static IRubyObjectopen(ThreadContext context, IRubyObject recv, IRubyObject[] args, Block block) orig_name(ThreadContext context) os_code(ThreadContext context) pos()Deprecated.pos(ThreadContext context) read(ThreadContext context, IRubyObject[] args) readbyte()Deprecated.readbyte(ThreadContext context) readchar()Deprecated.readchar(ThreadContext context) readline(ThreadContext context) readlines(ThreadContext context, IRubyObject[] args) readpartial(IRubyObject[] args) Deprecated.readpartial(ThreadContext context, IRubyObject[] args) rewind(ThreadContext context) set_lineno(IRubyObject lineArg) Deprecated.set_lineno(ThreadContext context, IRubyObject lineArg) Deprecated.ungetbyte(ThreadContext context, IRubyObject b) ungetc(ThreadContext context, IRubyObject cArg) unused()Deprecated.unused(ThreadContext context) static IRubyObjectzcat(ThreadContext context, IRubyObject klass, IRubyObject[] args, Block block) Document-method: Zlib::GzipReader.zcat call-seq: Zlib::GzipReader.zcat(io, options = {}, &block) => nil Zlib::GzipReader.zcat(io, options = {}) => string Decompresses all gzip data in the +io+, handling multiple gzip streams until the end of the +io+.Methods inherited from class org.jruby.ext.zlib.RubyGzipFile
close, closed_p, closed_p, comment, crc, ecopts, finish, finish, getBOM, getEcflags, getEcopts, getEnc, getEnc2, getInternalEncoding, getReadEncoding, getReadEncoding, isClosed, level, level, mtime, newInstance, newInstance, newStr, newStr, orig_name, os_code, path, respond_to, respond_to, set_sync, set_sync, setBOM, setEcflags, setEcopts, setEnc, setEnc2, sync, sync, to_io, to_io, wrap, wrap, wrap19Methods inherited from class org.jruby.RubyObject
attachToObjectSpace, callInit, callInit, callInit, callInit, callInit, callInit, callInit, callInit, callInit, callInit, convertToType, dig, dig1, dig2, eqlInternal, equalInternal, equals, finishObjectClass, getNativeClassIndex, hashCode, inspect, op_eqq, puts, specificEval, toRubyString, toStringMethods inherited from class org.jruby.RubyBasicObject
__id__, addFinalizer, addFinalizer, anyToString, asJavaString, asString, callMethod, callMethod, callMethod, callMethod, callMethod, callMethod, callMethod, callMethod, callMethod, callSuper, checkArrayType, checkCallMethod, checkCallMethod, checkFrozen, checkStringType, cloneSetup, compareTo, convertToArray, convertToFloat, convertToHash, convertToInteger, convertToInteger, convertToInteger, convertToString, copyInstanceVariablesInto, copySpecialInstanceVariables, dataGetStruct, dataGetStructChecked, dataWrapStruct, decode, display, dup, dupFinalizer, dupSetup, ensureInstanceVariablesSettable, eql, eql_p, eql_p, equal_p, evalUnder, extend, fastGetInstanceVariable, fastGetInternalVariable, fastHasInstanceVariable, fastHasInternalVariable, fastSetInstanceVariable, fastSetInternalVariable, finishBasicObjectClass, forEachInstanceVariable, forEachInstanceVariableName, freeze, frozen_p, getCurrentContext, getFFIHandle, getFlag, getInstanceEvalClass, getInstanceEvalClass, getInstanceVariable, getInstanceVariableList, getInstanceVariableNameList, getInstanceVariables, getInternalVariable, getInternalVariables, getJavaClass, getMarshalVariableList, getMetaClass, getMetaClass, getNativeHandle, getNativeTypeIndex, getObjectId, getRuntime, getSingletonClass, getSingletonClassClone, getSingletonClassCloneAndAttach, getSingletonClassCloneAndAttach, getType, getVariable, getVariableCount, getVariableList, getVariableNameList, hash, hash, hashyInspect, hasInstanceVariable, hasInstanceVariables, hasInternalVariable, hasVariables, id, infectBy, initialize, initialize_copy, initialize_copy, inspect, inspect, inspectHashCode, instance_eval, instance_eval, instance_eval, instance_eval, instance_eval, instance_exec, instance_of_p, instance_variable_defined_p, instance_variable_get, instance_variable_set, instance_variables, isBuiltin, isClass, isFalse, isFrozen, isImmediate, isModule, isNil, isSpecialConst, isSpecialObject, isTaint, isTrue, isUntrusted, kind_of_p, makeMetaClass, makeMetaClass, makeMetaClassBootstrap, method, method, method, method_missing, methods, methods, nil_p, nonFixnumHashCode, nonFixnumHashCode, OBJ_INIT_COPY, objInitCopy, op_cmp, op_equal, op_match, op_not, op_not_equal, op_not_match, private_methods, protected_methods, public_methods, rbClone, rbClone, rbInspect, remove_instance_variable, removeFinalizers, removeInstanceVariable, removeInternalVariable, respond_to_p, respond_to_p, respondsTo, respondsToMissing, respondsToMissing, send, send, send, send, send, setFFIHandle, setFlag, setFrozen, setInstanceVariable, setInternalVariable, setMetaClass, setNativeHandle, setTaint, setUntrusted, setVariable, singleton_method, singleton_method, singleton_method_added, singleton_method_removed, singleton_method_undefined, singleton_methods, singletonClass, specificEval, specificEval, specificEval, specificEval, syncVariables, syncVariables, taint, taint, tainted_p, testFrozen, testFrozen, to_a, to_a, to_s, to_s, toJava, trust, type, untaint, untrust, untrusted_p, validateInstanceVariable, validateInstanceVariable, validateInstanceVariable, variableTableContains, variableTableFastContains, variableTableFastFetch, variableTableFastStore, variableTableFetch, variableTableRemove, variableTableStore, variableTableSync, yieldUnder, yieldUnderMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface org.jruby.runtime.builtin.IRubyObject
checkStringType19, dup, marshalLiveVariables
-
Constructor Details
-
JZlibRubyGzipReader
-
-
Method Details
-
newInstance
public static IRubyObject newInstance(ThreadContext context, IRubyObject recv, IRubyObject[] args, Block block) -
newInstance
@Deprecated(since="10.0.0.0") public static JZlibRubyGzipReader newInstance(IRubyObject recv, IRubyObject[] args) Deprecated. -
newInstance
public static JZlibRubyGzipReader newInstance(ThreadContext context, RubyClass klass, IRubyObject[] args) -
open
public static IRubyObject open(ThreadContext context, IRubyObject recv, IRubyObject[] args, Block block) -
initialize
-
initialize
-
rewind
-
lineno
-
lineno
Deprecated. -
readline
-
gets
-
read
-
readpartial
Deprecated. -
readpartial
-
set_lineno
Deprecated. -
set_lineno
-
pos
Deprecated. -
pos
-
readchar
Deprecated. -
readchar
-
getc
Deprecated. -
getbyte
-
getbyte
Deprecated. -
readbyte
Deprecated. -
readbyte
-
getc
-
close
- Overrides:
closein classRubyGzipFile
-
eof
Deprecated. -
eof
-
eof_p
Deprecated. -
eof_p
-
unused
Deprecated. -
unused
-
crc
- Overrides:
crcin classRubyGzipFile
-
os_code
- Overrides:
os_codein classRubyGzipFile
-
orig_name
- Overrides:
orig_namein classRubyGzipFile
-
comment
- Overrides:
commentin classRubyGzipFile
-
each
-
each_line
-
ungetc
-
ungetbyte
Deprecated. -
ungetbyte
-
readlines
-
each_byte
-
each_char
-
zcat
public static IRubyObject zcat(ThreadContext context, IRubyObject klass, IRubyObject[] args, Block block) Document-method: Zlib::GzipReader.zcat call-seq: Zlib::GzipReader.zcat(io, options = {}, &block) => nil Zlib::GzipReader.zcat(io, options = {}) => string Decompresses all gzip data in the +io+, handling multiple gzip streams until the end of the +io+. There should not be any non-gzip data after the gzip streams. If a block is given, it is yielded strings of uncompressed data, and the method returns +nil+. If a block is not given, the method returns the concatenation of all uncompressed data in all gzip streams.
-