Enum Class CallConfiguration

java.lang.Object
java.lang.Enum<CallConfiguration>
org.jruby.internal.runtime.methods.CallConfiguration
All Implemented Interfaces:
Serializable, Comparable<CallConfiguration>, Constable

public enum CallConfiguration extends Enum<CallConfiguration>
  • Enum Constant Details

  • Method Details

    • values

      public static CallConfiguration[] values()
      Returns an array containing the constants of this enum class, in the order they are declared.
      Returns:
      an array containing the constants of this enum class, in the order they are declared
    • valueOf

      public static CallConfiguration valueOf(String name)
      Returns the enum constant of this class with the specified name. The string must match exactly an identifier used to declare an enum constant in this class. (Extraneous whitespace characters are not permitted.)
      Parameters:
      name - the name of the enum constant to be returned.
      Returns:
      the enum constant with the specified name
      Throws:
      IllegalArgumentException - if this enum class has no constant with the specified name
      NullPointerException - if the argument is null
    • getCallerCallConfigByAnno

      @Deprecated(since="10.0.3.0") public static CallConfiguration getCallerCallConfigByAnno(JRubyMethod jrubyMethod)
      Deprecated.
      Produce a CallConfiguration that represents what *caller* methods must prepare for the method with this annotation.
      See Also:
    • getCallConfigByAnno

      public static CallConfiguration getCallConfigByAnno(JRubyMethod anno)
      Produce a CallConfiguration name that represents what must be prepared around calls to the method with this annotation.
    • getCallConfig

      public static CallConfiguration getCallConfig(boolean frame)
      Given a frame and scope requirement, return the name of the appropriate CallConfiguration.
      See Also:
    • framing

      public final Framing framing()
    • scoping

      public final Scoping scoping()