Enum Constant Summary
Enum Constants
Method Summary
All Methods Static Methods Concrete Methods
Returns the enum constant of this class with the specified name.
Returns an array containing the constants of this enum class, in
the order they are declared.
Methods inherited from class java.lang.Enum
clone , compareTo , describeConstable , equals , finalize , getDeclaringClass , hashCode , name , ordinal , toString , valueOf
Enum Constant Details
BINDING_HAS_ESCAPED
public static final IRFlags BINDING_HAS_ESCAPED
HAS_END_BLOCKS
public static final IRFlags HAS_END_BLOCKS
REQUIRES_DYNSCOPE
public static final IRFlags REQUIRES_DYNSCOPE
REQUIRES_LASTLINE
public static final IRFlags REQUIRES_LASTLINE
REQUIRES_BACKREF
public static final IRFlags REQUIRES_BACKREF
REQUIRES_VISIBILITY
public static final IRFlags REQUIRES_VISIBILITY
REQUIRES_BLOCK
public static final IRFlags REQUIRES_BLOCK
REQUIRES_SELF
public static final IRFlags REQUIRES_SELF
REQUIRES_METHODNAME
public static final IRFlags REQUIRES_METHODNAME
REQUIRES_LINE
public static final IRFlags REQUIRES_LINE
REQUIRES_CLASS
public static final IRFlags REQUIRES_CLASS
REQUIRES_FILENAME
public static final IRFlags REQUIRES_FILENAME
REQUIRES_SCOPE
public static final IRFlags REQUIRES_SCOPE
FLAGS_COMPUTED
public static final IRFlags FLAGS_COMPUTED
Field Details
REQUIRE_ALL_FRAME_EXCEPT_SCOPE
Method Details
values
Returns an array containing the constants of this enum class, in
the order they are declared.
Returns:
an array containing the constants of this enum class, in the order they are declared
valueOf
Returns the enum constant of this class with the specified name.
The string must match exactly an identifier used to declare an
enum constant in this class. (Extraneous whitespace characters are
not permitted.)
Parameters:
name - the name of the enum constant to be returned.
Returns:
the enum constant with the specified name
Throws:
IllegalArgumentException - if this enum class has no constant with the specified name
NullPointerException - if the argument is null