Enum Constant Summary
Enum Constants
Method Summary
All Methods Static Methods Concrete Methods
Returns the enum constant of this class with the specified name.
Returns an array containing the constants of this enum class, in
the order they are declared.
Methods inherited from class java.lang.Enum
clone , compareTo , describeConstable , equals , finalize , getDeclaringClass , hashCode , name , ordinal , toString , valueOf
Enum Constant Details
BOOK_KEEPING_OP
public static final OpClass BOOK_KEEPING_OP
BRANCH_OP
public static final OpClass BRANCH_OP
CALL_OP
public static final OpClass CALL_OP
FLOAT_OP
public static final OpClass FLOAT_OP
OTHER_OP
public static final OpClass OTHER_OP
Method Details
values
Returns an array containing the constants of this enum class, in
the order they are declared.
Returns:
an array containing the constants of this enum class, in the order they are declared
valueOf
Returns the enum constant of this class with the specified name.
The string must match exactly an identifier used to declare an
enum constant in this class. (Extraneous whitespace characters are
not permitted.)
Parameters:
name - the name of the enum constant to be returned.
Returns:
the enum constant with the specified name
Throws:
IllegalArgumentException - if this enum class has no constant with the specified name
NullPointerException - if the argument is null