Uses of Enum Class
org.jruby.ir.Operation
Packages that use Operation
Package
Description
-
Uses of Operation in org.jruby.ir
Methods in org.jruby.ir that return OperationModifier and TypeMethodDescriptionstatic OperationOperation.fromOrdinal(int value) static OperationReturns the enum constant of this class with the specified name.static Operation[]Operation.values()Returns an array containing the constants of this enum class, in the order they are declared. -
Uses of Operation in org.jruby.ir.dataflow.analyses
Methods in org.jruby.ir.dataflow.analyses that return OperationModifier and TypeMethodDescriptionUnboxableOpsAnalysisProblem.getUnboxedOp(String name, Class operandType) -
Uses of Operation in org.jruby.ir.instructions
Methods in org.jruby.ir.instructions that return OperationConstructors in org.jruby.ir.instructions with parameters of type OperationModifierConstructorDescriptionBranchInstr(Operation op) protectedCallBase(IRScope scope, Operation op, CallType callType, RubySymbol name, Operand receiver, Operand[] args, Operand closure, int flags, boolean potentiallyRefined) protectedCallInstr(IRScope scope, Operation op, CallType callType, Variable result, RubySymbol name, Operand receiver, Operand[] args, Operand closure, int flags, boolean potentiallyRefined) GetInstr(Operation op, Variable result, Operand source, RubySymbol name) MultipleAsgnBase(Operation op, Variable result, Operand array, int index) NoOperandInstr(Operation operation) NoOperandResultBaseInstr(Operation operation, Variable result) NOperandInstr(Operation operation, Operand[] operands) NOperandResultBaseInstr(Operation operation, Variable result, Operand[] operands) NoResultCallInstr(IRScope scope, Operation op, CallType callType, RubySymbol name, Operand receiver, Operand[] args, Operand closure, int flags, boolean isPotentiallyRefined) OneOperandBranchInstr(Operation op, Label jumpTarget, Operand value) OneOperandInstr(Operation operation, Operand operand1) OneOperandResultBaseInstr(Operation operation, Variable result, Operand operand1) protectedPutInstr(Operation op, Operand target, RubySymbol name, Operand value) ReceiveArgBase(Operation op, Variable result, Variable keywords) ReceiveExceptionBase(Operation op, Variable result) ReceiveIndexedArgBase(Operation op, Variable result, Variable keywords, int argIndex) ResultBaseInstr(Operation operation, Variable result) ReturnBase(Operation op, Operand returnValue) ReturnInstr(Operation operation, Operand returnValue) TwoOperandBranchInstr(Operation op, Label jumpTarget, Operand arg1, Operand arg2) TwoOperandInstr(Operation operation, Operand operand1, Operand operand2) TwoOperandResultBaseInstr(Operation operation, Variable result, Operand operand1, Operand operand2) UnresolvedSuperInstr(IRScope scope, Operation op, Variable result, Operand receiver, Operand[] args, Operand closure, int flags, boolean isPotentiallyRefined) -
Uses of Operation in org.jruby.ir.instructions.boxing
Constructors in org.jruby.ir.instructions.boxing with parameters of type Operation -
Uses of Operation in org.jruby.ir.instructions.specialized
Constructors in org.jruby.ir.instructions.specialized with parameters of type OperationModifierConstructorDescriptionOneOperandArgNoBlockCallInstr(IRScope scope, Operation op, CallType callType, Variable result, RubySymbol name, Operand receiver, Operand[] args, int flags, boolean isPotentiallyRefined) protectedZeroOperandArgNoBlockCallInstr(IRScope scope, Operation op, CallType callType, Variable result, RubySymbol name, Operand receiver, Operand[] args, int flags, boolean isPotentiallyRefined) -
Uses of Operation in org.jruby.ir.interpreter
Methods in org.jruby.ir.interpreter with parameters of type OperationModifier and TypeMethodDescriptionstatic voidprotected static voidInterpreterEngine.interpretFloatOp(AluInstr instr, Operation op, double[] floats, boolean[] booleans) protected static voidInterpreterEngine.interpretIntOp(AluInstr instr, Operation op, long[] fixnums, boolean[] booleans) protected static voidInterpreterEngine.processBookKeepingOp(ThreadContext context, Block block, Instr instr, Operation operation, String name, IRubyObject[] args, IRubyObject self, Block blockArg, RubyModule implClass, DynamicScope currDynScope, Object[] temp, StaticScope currScope) protected static voidInterpreterEngine.processCall(ThreadContext context, Instr instr, Operation operation, DynamicScope currDynScope, StaticScope currScope, Object[] temp, IRubyObject self, String name) protected static voidExitableInterpreterEngine.processOtherOp(ThreadContext context, Block block, Instr instr, Operation operation, DynamicScope currDynScope, StaticScope currScope, Object[] temp, IRubyObject self) protected static voidInterpreterEngine.processOtherOp(ThreadContext context, Block block, Instr instr, Operation operation, DynamicScope currDynScope, StaticScope currScope, Object[] temp, IRubyObject self, double[] floats, long[] fixnums, boolean[] booleans) protected static voidStartupInterpreterEngine.processOtherOp(ThreadContext context, Block block, Instr instr, Operation operation, DynamicScope currDynScope, StaticScope currScope, Object[] temp, IRubyObject self) protected static IRubyObjectInterpreterEngine.processReturnOp(ThreadContext context, Block block, Instr instr, Operation operation, DynamicScope currDynScope, Object[] temp, IRubyObject self, StaticScope currScope) protected static voidInterpreterEngine.receiveArg(ThreadContext context, Instr i, Operation operation, IRubyObject self, IRubyObject[] args, boolean ruby2Keywords, StaticScope currScope, DynamicScope currDynScope, Object[] temp, Object exception, Block blockArg) -
Uses of Operation in org.jruby.ir.persistence
Methods in org.jruby.ir.persistence that return OperationModifier and TypeMethodDescriptionIRReaderDecoder.decodeOperation()IRReaderStream.decodeOperation()Methods in org.jruby.ir.persistence with parameters of type Operation