public interface RubyObjectHolderProxy
Additional interface implemented by proxies that back Java interfaces by
Ruby objects so that we can get back to the original Ruby object from the proxy.
- Author:
- nicksieger
-
Method Summary
-
Method Details
-
__ruby_object
IRubyObject __ruby_object()
-