Uses of Class
org.jruby.java.proxies.BlockInterfaceTemplate
Packages that use BlockInterfaceTemplate
-
Uses of BlockInterfaceTemplate in org.jruby.java.codegen
Methods in org.jruby.java.codegen that return types with arguments of type BlockInterfaceTemplateModifier and TypeMethodDescriptionstatic Constructor<? extends BlockInterfaceTemplate> static Constructor<? extends BlockInterfaceTemplate> BlockInterfaceGenerator.getConstructor(Ruby runtime, Class<?> interfaceType) -
Uses of BlockInterfaceTemplate in org.jruby.javasupport
Methods in org.jruby.javasupport that return types with arguments of type BlockInterfaceTemplateModifier and TypeMethodDescriptionstatic <T> Constructor<? extends BlockInterfaceTemplate> Java.getBlockToInterfaceConstructor(Ruby runtime, Class<T> targetType) Fast path for converting a proc to a Java interface proxy, bypassing the singleton class setup.Method parameters in org.jruby.javasupport with type arguments of type BlockInterfaceTemplateModifier and TypeMethodDescriptionstatic <T> TJava.newBlockToInterfaceInstance(RubyProc proc, Constructor<? extends BlockInterfaceTemplate> constructor)