java.lang.Object
org.jruby.RubyBasicObject
org.jruby.RubyObject
org.jruby.javasupport.JavaObject
org.jruby.javasupport.JavaClass
- All Implemented Interfaces:
Serializable,Cloneable,Comparable<IRubyObject>,InstanceVariables,InternalVariables,IRubyObject,CoreObjectType
Deprecated.
since 9.3
Java::JavaClass wrapping is no longer used with JRuby.
The (automatic) Java proxy wrapping works with Java classes, use the
java.lang.Class with JRuby's
Java scripting capabilities.- Author:
- jpetersen
- See Also:
-
Nested Class Summary
Nested classes/interfaces inherited from class org.jruby.RubyObject
RubyObject.DataNested classes/interfaces inherited from class org.jruby.RubyBasicObject
RubyBasicObject.Finalizer -
Field Summary
FieldsFields inherited from class org.jruby.RubyObject
IVAR_INSPECTING_OBJECT_ALLOCATOR, OBJECT_ALLOCATOR, REIFYING_OBJECT_ALLOCATORFields inherited from class org.jruby.RubyBasicObject
ALL_F, BASICOBJECT_ALLOCATOR, COMPARE_BY_IDENTITY_F, ERR_INSECURE_SET_INST_VAR, FALSE_F, FL_USHIFT, flags, FROZEN_F, IS_OVERLAID_F, metaClass, NEVER, NIL_F, REFINED_MODULE_F, STAMP_OFFSET, TAINTED_F, UNDEF, USER0_F, USER1_F, USER2_F, USER3_F, USER4_F, USER5_F, USER6_F, USER7_F, USER8_F, USER9_F, USERA_F, VAR_TABLE_OFFSET, varTable, varTableStampFields inherited from interface org.jruby.runtime.builtin.IRubyObject
NULL_ARRAY -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionstatic booleanassignable(Class<?> target, Class<?> from) Deprecated.concatArrays(ThreadContext context, JavaArray original, JavaArray additional) Deprecated.concatArrays(ThreadContext context, JavaArray original, IRubyObject additional) Deprecated.emptyJavaArray(ThreadContext context) Deprecated.final booleanDeprecated.This override does not do a "checked" dispatch.static JavaClassfor_name(IRubyObject recv, IRubyObject name) Deprecated.static JavaClassforNameQuiet(Ruby runtime, String className) Deprecated.static JavaClassforNameVerbose(Ruby runtime, String className) Deprecated.static JavaClassDeprecated.static Class<?>[]getArgumentTypes(ThreadContext context, IRubyObject[] args, int offset) Deprecated.static Constructor[]getConstructors(Class<?> clazz) Deprecated.static Class<?>[]getDeclaredClasses(Class<?> clazz) Deprecated.static Field[]getDeclaredFields(Class<?> clazz) Deprecated.static Field[]Deprecated.static Class<?> getJavaClass(ThreadContext context, RubyModule proxy) Deprecated.static Class<?> getJavaClassIfProxy(ThreadContext context, RubyModule type) Deprecated.static JavaCallablegetMatchingCallable(Ruby runtime, Class<?> javaClass, String methodName, Class<?>[] argumentTypes) Deprecated.final RubyClassDeprecated.final RubyModuleDeprecated.static RubyArraygetRubyArray(Ruby runtime, Class<?>[] classes) Deprecated.static StringgetSimpleName(Class<?> clazz) Deprecated.final inthashCode()Deprecated.This override does not do "checked" dispatch since Object usually has #hash defined.inspect()Deprecated.inspect(ThreadContext context) Deprecated.Returns a string containing a human-readable representation of obj.final booleanisAssignableFrom(Class<?> clazz) Deprecated.static booleanisProxyType(ThreadContext context, RubyModule proxy) Deprecated.Note: Interal APIstatic IRubyObjectjava_class(ThreadContext context, RubyModule type) Deprecated.final ClassDeprecated.static JavaClassresolveType(ThreadContext context, IRubyObject type) Deprecated.static RubyArraytoRubyArray(Ruby runtime, Class<?>[] classes) Deprecated.Methods inherited from class org.jruby.javasupport.JavaObject
createJavaObjectClass, dataGetStruct, dataWrapStruct, get_java_class, get_java_class, getJavaClass, getValue, hash, is_java_proxy, is_java_proxy, java_class, java_type, java_type, length, length, marshal_dump, marshal_load, op_equal, op_equal, op_equal, ruby_synchronized, ruby_synchronized, same, same, to_s, to_s, toJava, wrap, wrapMethods inherited from class org.jruby.RubyObject
attachToObjectSpace, callInit, callInit, callInit, callInit, callInit, callInit, callInit, callInit, callInit, callInit, convertToType, dig, dig1, dig2, eqlInternal, equalInternal, finishObjectClass, getNativeClassIndex, inspect, op_eqq, puts, specificEval, toRubyString, toStringMethods inherited from class org.jruby.RubyBasicObject
__id__, addFinalizer, addFinalizer, anyToString, asJavaString, asString, callMethod, callMethod, callMethod, callMethod, callMethod, callMethod, callMethod, callMethod, callMethod, callSuper, checkArrayType, checkCallMethod, checkCallMethod, checkFrozen, checkStringType, cloneSetup, compareTo, convertToArray, convertToFloat, convertToHash, convertToInteger, convertToInteger, convertToInteger, convertToString, copyInstanceVariablesInto, copySpecialInstanceVariables, dataGetStructChecked, decode, display, dup, dupFinalizer, dupSetup, ensureInstanceVariablesSettable, eql, eql_p, eql_p, equal_p, evalUnder, extend, fastGetInstanceVariable, fastGetInternalVariable, fastHasInstanceVariable, fastHasInternalVariable, fastSetInstanceVariable, fastSetInternalVariable, finishBasicObjectClass, forEachInstanceVariable, forEachInstanceVariableName, freeze, frozen_p, getCurrentContext, getFFIHandle, getFlag, getInstanceEvalClass, getInstanceEvalClass, getInstanceVariable, getInstanceVariableList, getInstanceVariableNameList, getInstanceVariables, getInternalVariable, getInternalVariables, getMarshalVariableList, getMetaClass, getMetaClass, getNativeHandle, getNativeTypeIndex, getObjectId, getRuntime, getSingletonClass, getSingletonClassClone, getSingletonClassCloneAndAttach, getSingletonClassCloneAndAttach, getType, getVariable, getVariableCount, getVariableList, getVariableNameList, hash, hashyInspect, hasInstanceVariable, hasInstanceVariables, hasInternalVariable, hasVariables, id, infectBy, initialize, initialize_copy, initialize_copy, inspectHashCode, instance_eval, instance_eval, instance_eval, instance_eval, instance_eval, instance_exec, instance_of_p, instance_variable_defined_p, instance_variable_get, instance_variable_set, instance_variables, isBuiltin, isClass, isFalse, isFrozen, isImmediate, isModule, isNil, isSpecialConst, isSpecialObject, isTaint, isTrue, isUntrusted, kind_of_p, makeMetaClass, makeMetaClass, makeMetaClassBootstrap, method, method, method, method_missing, methods, methods, nil_p, nonFixnumHashCode, nonFixnumHashCode, OBJ_INIT_COPY, objInitCopy, op_cmp, op_match, op_not, op_not_equal, op_not_match, private_methods, protected_methods, public_methods, rbClone, rbClone, rbInspect, remove_instance_variable, removeFinalizers, removeInstanceVariable, removeInternalVariable, respond_to_p, respond_to_p, respondsTo, respondsToMissing, respondsToMissing, send, send, send, send, send, setFFIHandle, setFlag, setFrozen, setInstanceVariable, setInternalVariable, setMetaClass, setNativeHandle, setTaint, setUntrusted, setVariable, singleton_method, singleton_method, singleton_method_added, singleton_method_removed, singleton_method_undefined, singleton_methods, singletonClass, specificEval, specificEval, specificEval, specificEval, syncVariables, syncVariables, taint, taint, tainted_p, testFrozen, testFrozen, to_a, to_a, to_s, trust, type, untaint, untrust, untrusted_p, validateInstanceVariable, validateInstanceVariable, validateInstanceVariable, variableTableContains, variableTableFastContains, variableTableFastFetch, variableTableFastStore, variableTableFetch, variableTableRemove, variableTableStore, variableTableSync, yieldUnder, yieldUnderMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface org.jruby.runtime.builtin.IRubyObject
checkStringType19, dup, marshalLiveVariables
-
Field Details
-
EMPTY_CLASS_ARRAY
Deprecated.
-
-
Constructor Details
-
JavaClass
Deprecated.
-
-
Method Details
-
equals
Deprecated.Description copied from class:RubyObjectThis override does not do a "checked" dispatch.- Overrides:
equalsin classJavaObject- Parameters:
other- object to compare- Returns:
- true if equals
- See Also:
-
hashCode
public final int hashCode()Deprecated.Description copied from class:RubyObjectThis override does not do "checked" dispatch since Object usually has #hash defined.- Overrides:
hashCodein classJavaObject- Returns:
- the hash code
- See Also:
-
getProxyModule
Deprecated. -
getProxyClass
Deprecated. -
get
Deprecated. -
getRubyArray
Deprecated. -
toRubyArray
Deprecated. -
javaClass
Deprecated. -
getJavaClass
@Deprecated(since="9.4.0.0") public static Class<?> getJavaClass(ThreadContext context, RubyModule proxy) Deprecated.- See Also:
-
getJavaClassIfProxy
@Deprecated(since="9.4.0.0") public static Class<?> getJavaClassIfProxy(ThreadContext context, RubyModule type) Deprecated.- See Also:
-
isProxyType
Deprecated.Note: Interal API
- See Also:
-
java_class
@Deprecated(since="9.4.0.0") public static IRubyObject java_class(ThreadContext context, RubyModule type) Deprecated.Returns the (reified or proxied) Java class if the passed Ruby module/class has one.- Parameters:
context-type-- Returns:
- Java proxy class, Java reified class or nil
-
resolveType
@Deprecated(since="9.3.0.0") public static JavaClass resolveType(ThreadContext context, IRubyObject type) Deprecated.Resolves a Java class from a passed type parameter. Uisng the rules accepted by `to_java(type)` in Ruby land.- Parameters:
context-type-- Returns:
- resolved type or null if resolution failed
-
forNameVerbose
Deprecated. -
forNameQuiet
Deprecated. -
for_name
Deprecated. -
inspect
Deprecated.Description copied from interface:IRubyObjectRubyMethod inspect.- Specified by:
inspectin interfaceIRubyObject- Overrides:
inspectin classRubyBasicObject- Returns:
- String
-
inspect
Deprecated.Description copied from class:RubyBasicObjectReturns a string containing a human-readable representation of obj. If not overridden, uses theto_smethod to generate the string. [ 1, 2, 3..4, 'five' ].inspect #=> "[1, 2, 3..4, \"five\"]" Time.new.inspect #=> "Wed Apr 09 08:54:39 CDT 2003"- Specified by:
inspectin interfaceIRubyObject- Overrides:
inspectin classRubyBasicObject
-
getSimpleName
Deprecated. -
getMatchingCallable
public static JavaCallable getMatchingCallable(Ruby runtime, Class<?> javaClass, String methodName, Class<?>[] argumentTypes) Deprecated. -
getArgumentTypes
Deprecated. -
emptyJavaArray
Deprecated. -
concatArrays
@Deprecated(since="9.4.0.0") public IRubyObject concatArrays(ThreadContext context, JavaArray original, JavaArray additional) Deprecated.Contatenate two Java arrays into a new one. The component type of the additional array must be assignable to the component type of the original array.- Parameters:
context-original-additional-- Returns:
-
concatArrays
@Deprecated(since="9.4.0.0") public IRubyObject concatArrays(ThreadContext context, JavaArray original, IRubyObject additional) Deprecated.The slow version for when concatenating a Java array of a different type.- Parameters:
context-original-additional-- Returns:
-
isAssignableFrom
Deprecated. -
assignable
Deprecated. -
getConstructors
Deprecated. -
getDeclaredClasses
Deprecated. -
getDeclaredFields
Deprecated. -
getFields
Deprecated.
-