java.lang.Object
org.jruby.RubyBasicObject
org.jruby.RubyObject
org.jruby.RubyModule
org.jruby.javasupport.JavaPackage
- All Implemented Interfaces:
Serializable,Cloneable,Comparable<IRubyObject>,InstanceVariables,InternalVariables,IRubyObject,CoreObjectType
A "thin" Java package wrapper (for the runtime to see them as Ruby objects).
- Since:
- 9K
Note: previously
JavaPackageModuleTemplatein Ruby code - Author:
- kares
- See Also:
-
Nested Class Summary
Nested classes/interfaces inherited from class org.jruby.RubyModule
RubyModule.Autoload, RubyModule.CacheEntryFactory, RubyModule.ConstantEntry, RubyModule.InvalidatorList<T>, RubyModule.JavaClassKindOf, RubyModule.KindOf, RubyModule.MethodClumper, RubyModule.ProfilingCacheEntryFactory, RubyModule.RefinementMethods, RubyModule.RespondToMissingMethod, RubyModule.SourceLocation, RubyModule.SynchronizedCacheEntryFactory, RubyModule.WrapperCacheEntryFactoryNested classes/interfaces inherited from class org.jruby.RubyObject
RubyObject.DataNested classes/interfaces inherited from class org.jruby.RubyBasicObject
RubyBasicObject.Finalizer -
Field Summary
Fields inherited from class org.jruby.RubyModule
baseName, BUILTIN_CONSTANT, cachedMethods, CACHEPROXY_F, classIndex, generation, generationObject, id, INCLUDED_INTO_REFINEMENT, includingHierarchies, IS_OVERLAID_F, kindOf, methodInvalidator, methodLocation, methods, MODULE_ALLOCATOR, NEEDSIMPL_F, NormalCacheEntryFactory, OMOD_SHARED, parent, REFINED_MODULE_F, superClass, TEMPORARY_NAMEFields inherited from class org.jruby.RubyObject
IVAR_INSPECTING_OBJECT_ALLOCATOR, OBJECT_ALLOCATOR, REIFYING_OBJECT_ALLOCATORFields inherited from class org.jruby.RubyBasicObject
ALL_F, BASICOBJECT_ALLOCATOR, ERR_INSECURE_SET_INST_VAR, FALSE_F, flags, FROZEN_F, metaClass, NEVER, NIL_F, STAMP_OFFSET, TAINTED_F, UNDEF, VAR_TABLE_OFFSET, varTable, varTableStampFields inherited from interface org.jruby.runtime.builtin.IRubyObject
NULL_ARRAY -
Method Summary
Modifier and TypeMethodDescriptionavailable_p(ThreadContext context) final IRubyObjectconst_get(ThreadContext context, IRubyObject name) final IRubyObjectconst_get(ThreadContext context, IRubyObject name, IRubyObject inherit) const_missing(ThreadContext context, IRubyObject name) final IRubyObjectfetchConstant(ThreadContext context, String name, boolean includePrivate) final booleanhasConstant(String name) inthashCode()This override does not do "checked" dispatch since Object usually has #hash defined.inspect(ThreadContext context) Returns a string containing a human-readable representation of obj.final booleanmethod_missing(ThreadContext context, IRubyObject name) method_missing(ThreadContext context, IRubyObject[] args) op_eqq(ThreadContext context, IRubyObject obj) rb_mod_eqqDeprecated.package_name(ThreadContext context) respond_to_missing_p(ThreadContext context, IRubyObject name) respond_to_missing_p(ThreadContext context, IRubyObject name, IRubyObject includePrivate) respond_to_p(ThreadContext context, IRubyObject name) respond_to_p(ThreadContext context, IRubyObject name, IRubyObject includePrivate) sealed_p(ThreadContext context) to_s()Deprecated.to_s(ThreadContext context) rb_mod_to_s<T> TConvert the object to the specified Java class, if possible.Methods inherited from class org.jruby.RubyModule
_module_function, _private, _protected, _public, addClassProvider, addIncludingHierarchy, addMethod, addMethod, addMethodInternal, addMethodInternal, addMethodSymbols, addMethodSymbols, addModuleFunction, addReadAttribute, addReadWriteAttribute, addToCache, addToCache, addWriteAttribute, alias_method, aliasMethod, ancestors, ancestors, append_features, append_features, attr, attr_accessor, attr_reader, attr_writer, autoload, autoload_p, autoload_p, autoloadingValue, autoloadingValue, baseName, becomeSynchronized, checkForCyclicPrepend, checkFrozen, checkValidBindTargetFrom, class_variable_defined_p, class_variable_get, class_variable_get, class_variable_get19, class_variable_set, class_variable_set, class_variable_set19, class_variables, class_variables, classIndex, cloneMethods, cloneMethods, const_added, const_defined_p, const_defined_p, const_get, const_get, const_get_1_9, const_get_2_0, const_missing, const_set, const_set, const_source_location, constantEntryFetch, constants, constants, constantsCommon, constantsCommon, constantTableContains, constantTableFetch, constantTableRemove, constantTableStore, constantTableStore, constantTableStore, constantTableStore, constDefined, constDefined, constDefinedAt, constDefinedAt, constDefinedFrom, constDefinedFrom, define_method, define_method, defineAlias, defineAlias, defineAnnotatedConstant, defineAnnotatedConstants, defineAnnotatedMethod, defineAnnotatedMethod, defineAnnotatedMethod, defineAnnotatedMethod, defineAnnotatedMethod, defineAnnotatedMethods, defineAnnotatedMethodsIndividually, defineAutoload, defineAutoload, defineClassUnder, defineClassUnder, defineClassUnder, defineConstant, defineConstant, defineConstant, defineConstantBootstrap, defineConstants, defineConstantsFrom, defineMethodFromBlock, defineMethodFromCallable, defineMethods, defineModuleUnder, defineModuleUnder, defineOrGetClassUnder, defineOrGetClassUnder, defineOrGetClassUnder, defineOrGetClassUnder, defineOrGetModuleUnder, defineOrGetModuleUnder, defineOrGetModuleUnder, deleteClassVariable, deleteConstant, deleteConstant, deprecate_constant, deprecate_constant, deprecateConstant, deprecateConstant, discoverInstanceVariables, ensureClassVariablesSettable, ensureConstantsSettable, equals, exportMethod, extend_object, extend_object, extended, extendObject, fastSetConstant, fetchClassVariable, fetchConstant, fetchConstant, fetchConstant, fetchConstantEntry, fetchConstantEntry, findImplementer, finishAutoload, finishAutoload, finishCreateModuleClass, finishModuleClass, finishRefinementClass, freeze, getAncestorList, getAutoloadConstant, getAutoloadConstant, getAutoloadConstant, getAutoloadConstant, getAutoloadFile, getAutoloadMap, getAutoloadMapForWrite, getBaseName, getCachedMethods, getCacheProxy, getClass, getClass, getClassIndex, getClassVar, getClassVar, getClassVar, getClassVar, getClassVariableNameList, getClassVariables, getClassVariablesForRead, getClassVarQuiet, getConstant, getConstant, getConstant, getConstant, getConstant, getConstant, getConstantAt, getConstantAt, getConstantAt, getConstantAt, getConstantAtSpecial, getConstantAtSpecial, getConstantFrom, getConstantFrom, getConstantFromConstMissing, getConstantFromConstMissing, getConstantFromNoConstMissing, getConstantFromNoConstMissing, getConstantFromNoConstMissing, getConstantFromNoConstMissing, getConstantMap, getConstantMapForWrite, getConstantNames, getConstantNames, getConstantNoConstMissing, getConstantNoConstMissing, getConstantNoConstMissing, getConstantNoConstMissing, getConstantNoConstMissing, getConstantNoConstMissing, getConstantNoConstMissingSkipAutoload, getConstantNoConstMissingSkipAutoload, getConstantSourceLocation, getConstantSourceLocation, getConstantWithAutoload, getConstantWithAutoload, getDelegate, getGeneration, getGenerationObject, getIdTest, getIncludingHierarchiesForWrite, getInvalidator, getJavaProxy, getMethodLocation, getMethods, getMethodsForWrite, getModule, getModule, getName, getName, getNativeClassIndex, getOrigin, getParent, getRealModule, getRefinements, getRefinementsForWrite, getSimpleName, getSimpleName, getSuperClass, hasAncestor, hasAutoload, hasClassVariable, hash, hasInternalModuleVariable, hasModuleInHierarchy, hasModuleInPrepends, hasPrepends, include, include, include, include, include_p, included, included_modules, includeModule, includeModule, initialize, initializeCopiedModule, instance_method, instance_method, instance_methods, instance_methods, instance_methods19, instanceMethods, instanceMethods, instanceMethods, invalidateCacheDescendants, invalidateCacheDescendants, invalidateConstantCache, invalidateConstantCache, invalidateConstantCaches, invalidateCoreClasses, invalidateMethodCache, isClass, isClassVarDefined, isConstantDefined, isConstantDefined, isConstantDefined, isIncluded, isIncludedIntoRefinement, isInstance, isKindOfModule, isMethodBound, isMethodBuiltin, isModule, isPrepended, isRefinement, isSame, isSameOrigin, isSingleton, isSynchronized, isValidConstantName, isValidConstantPath, kindOf, loadPopulatorFor, marshalTo, marshalTo, method_added, method_defined_p, method_defined_p, method_removed, method_undefined, methodAdded, mix, mix, module_eval, module_eval, module_eval, module_eval, module_eval, module_exec, module_exec, module_function, name, name, needsImplementer, nesting, newActivatedRefinementsMap, newIdTest, newMethod, newMethod, newMethod, newMethod, newMethod, newMethod, newMethod, newModule, newModule, newModule, newModule, newModuleBootstrap, newRefinementsMap, newRefinementsMap, op_cmp, op_cmp, op_equal, op_ge, op_ge, op_gt, op_gt, op_le, op_le, op_lt, op_lt, prepend, prepend_features, prepend_features, prepended, prependModule, prependModule, private_class_method, private_class_method, private_constant, private_constant, private_instance_methods, private_instance_methods, private_method_defined, private_method_defined, protected_instance_methods, protected_instance_methods, protected_method_defined, protected_method_defined, public_class_method, public_class_method, public_constant, public_constant, public_instance_method, public_instance_method, public_instance_methods, public_instance_methods, public_instance_methods19, public_method_defined, public_method_defined, publicConstDefinedFrom, publicConstDefinedFrom, putAlias, putAlias, putAlias, putAlias, putMethod, putMethod, rbPrivate, rbProtected, rbPublic, refine, refined_class, refinements, remove_class_variable, remove_class_variable19, remove_const, remove_method, removeClassProvider, removeClassVariable, removeClassVariable, removeMethod, resolveRefinedMethod, resolveUndefConstant, respondsToMethod, respondsToMethod, retrieveMethod, ruby2_keywords, rubyBaseName, rubyBaseName, rubyName, rubyName, searchAncestor, searchInternalModuleVariable, searchMethod, searchMethodCommon, searchMethodEntryInner, searchMethodInner, searchWithCache, searchWithCache, searchWithRefinements, set_temporary_name, setBaseName, setCacheProxy, setClassVar, setClassVar, setConstant, setConstant, setConstant, setConstant, setConstant, setConstant, setConstantQuiet, setConstantQuiet, setConstantVisibility, setConstantVisibility, setInternalModuleVariable, setJavaProxy, setMethodLocation, setMethodVisibility, setMethodVisibility, setParent, setRefinements, setSuperClass, singleton_class_p, sites, storeClassVariable, storeClassVariable, storeConstant, storeConstant, storeConstant, storeConstant, storeConstant, superClass, superClass, symbolName, symbolName, syncClassVariables, syncConstants, tap, target, testModuleMatch, undef, undef_method, undefined_instance_method, undefinedMethodMessage, undefineMethod, undefMethods, unmarshalFrom, unmarshalFrom, updateGeneration, used_modules, used_refinements, using, usingModule, usingTemporaryName, validateClassVariable, validateClassVariable, validateClassVariable, validateClassVariable, validateConstant, validateConstant, validateConstantMethods inherited from class org.jruby.RubyObject
attachToObjectSpace, callInit, callInit, callInit, callInit, callInit, callInit, callInit, callInit, callInit, callInit, dig, dig1, dig2, eqlInternal, equalInternal, finishObjectClass, inspect, puts, toRubyString, toStringMethods inherited from class org.jruby.RubyBasicObject
__id__, addFinalizer, addFinalizer, anyToString, asJavaString, asString, callMethod, callMethod, callMethod, callMethod, callMethod, callMethod, callMethod, checkArrayType, checkCallMethod, checkCallMethod, checkStringType, cloneSetup, compareTo, convertToArray, convertToFloat, convertToHash, convertToInteger, convertToInteger, convertToString, copyInstanceVariablesInto, copySpecialInstanceVariables, dataGetStruct, dataWrapStruct, decode, display, dup, dupFinalizer, dupSetup, ensureInstanceVariablesSettable, eql, eql_p, eql_p, equal_p, evalUnder, extend, finishBasicObjectClass, forEachInstanceVariable, forEachInstanceVariableName, frozen_p, getCurrentContext, getFFIHandle, getFlag, getInstanceEvalClass, getInstanceEvalClass, getInstanceVariable, getInstanceVariableList, getInstanceVariableNameList, getInstanceVariables, getInternalVariable, getInternalVariables, getJavaClass, getMarshalVariableList, getMetaClass, getMetaClass, getObjectId, getRuntime, getSingletonClass, getSingletonClassClone, getSingletonClassCloneAndAttach, getSingletonClassCloneAndAttach, getType, getVariable, getVariableList, getVariableNameList, hash, hashyInspect, hashyInspect, hasInstanceVariable, hasInstanceVariables, hasInternalVariable, hasVariables, id, infectBy, initialize, initialize_copy, initialize_copy, inspect, inspectHashCode, instance_eval, instance_eval, instance_eval, instance_eval, instance_eval, instance_exec, instance_of_p, instance_variable_defined_p, instance_variable_get, instance_variable_set, instance_variables, isBuiltin, isFalse, isFrozen, isImmediate, isNil, isSpecialConst, isSpecialObject, isTaint, isTrue, kind_of_p, makeMetaClass, makeMetaClass, makeMetaClassBootstrap, method, method, method, method_missing, methods, nil_p, nonFixnumHashCode, nonFixnumHashCode, OBJ_INIT_COPY, objInitCopy, op_match, op_not, op_not_equal, op_not_match, private_methods, protected_methods, public_methods, rbClone, rbClone, rbInspect, remove_instance_variable, removeFinalizers, removeInstanceVariable, removeInternalVariable, respond_to_p, respondsTo, respondsToMissing, respondsToMissing, send, send, send, send, send, setFFIHandle, setFlag, setFrozen, setInstanceVariable, setInternalVariable, setMetaClass, setTaint, setVariable, singleton_method, singleton_method, singleton_method_added, singleton_method_removed, singleton_method_undefined, singleton_methods, singletonClass, specificEval, specificEval, specificEval, specificEval, syncVariables, taint, taint, tainted_p, testFrozen, testFrozen, to_a, type, untaint, validateInstanceVariable, variableTableContains, variableTableFetch, variableTableRemove, variableTableStore, variableTableSync, yieldUnder, yieldUnderMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface org.jruby.runtime.builtin.IRubyObject
checkStringType19, dup, marshalLiveVariables
-
Method Details
-
getPackageName
-
package_name
Deprecated. -
package_name
-
to_s
Deprecated.- Overrides:
to_sin classRubyModule- Returns:
- ""
-
to_s
Description copied from class:RubyModulerb_mod_to_s- Overrides:
to_sin classRubyModule
-
inspect
Description copied from class:RubyBasicObjectReturns a string containing a human-readable representation of obj. If not overridden, uses theto_smethod to generate the string. [ 1, 2, 3..4, 'five' ].inspect #=> "[1, 2, 3..4, \"five\"]" Time.new.inspect #=> "Wed Apr 09 08:54:39 CDT 2003"- Specified by:
inspectin interfaceIRubyObject- Overrides:
inspectin classRubyBasicObject
-
op_eqq
Description copied from class:RubyModulerb_mod_eqq- Specified by:
op_eqqin interfaceIRubyObject- Overrides:
op_eqqin classRubyModule
-
const_missing
-
const_get
- Overrides:
const_getin classRubyModule
-
const_get
- Overrides:
const_getin classRubyModule
-
hasConstant
- Overrides:
hasConstantin classRubyModule
-
fetchConstant
- Overrides:
fetchConstantin classRubyModule
-
respond_to_p
-
respond_to_p
public IRubyObject respond_to_p(ThreadContext context, IRubyObject name, IRubyObject includePrivate) -
respond_to_missing_p
-
respond_to_missing_p
public IRubyObject respond_to_missing_p(ThreadContext context, IRubyObject name, IRubyObject includePrivate) -
method_missing
-
method_missing
-
isAvailable
public final boolean isAvailable() -
available_p
-
sealed_p
-
toJava
Description copied from interface:IRubyObjectConvert the object to the specified Java class, if possible.- Specified by:
toJavain interfaceIRubyObject- Overrides:
toJavain classRubyModule- Type Parameters:
T- type- Parameters:
target- The target type to which the object should be converted.- Returns:
- java type
- See Also:
-
hashCode
public int hashCode()Description copied from class:RubyObjectThis override does not do "checked" dispatch since Object usually has #hash defined.- Overrides:
hashCodein classRubyModule- Returns:
- the hash code
- See Also:
-