java.lang.Object
org.jruby.RubyBasicObject
org.jruby.RubyObject
org.jruby.javasupport.proxy.JavaProxyReflectionObject
org.jruby.javasupport.proxy.JavaProxyClass.ProxyMethodImpl
- All Implemented Interfaces:
Serializable,Cloneable,Comparable<IRubyObject>,ParameterTypes,JavaProxyMethod,InstanceVariables,InternalVariables,IRubyObject,CoreObjectType
- Enclosing class:
JavaProxyClass
public static class JavaProxyClass.ProxyMethodImpl
extends JavaProxyReflectionObject
implements JavaProxyMethod
- See Also:
-
Nested Class Summary
Nested classes/interfaces inherited from class org.jruby.RubyObject
RubyObject.DataNested classes/interfaces inherited from class org.jruby.RubyBasicObject
RubyBasicObject.Finalizer -
Field Summary
Fields inherited from class org.jruby.RubyObject
IVAR_INSPECTING_OBJECT_ALLOCATOR, OBJECT_ALLOCATOR, REIFYING_OBJECT_ALLOCATORFields inherited from class org.jruby.RubyBasicObject
ALL_F, BASICOBJECT_ALLOCATOR, ERR_INSECURE_SET_INST_VAR, FALSE_F, flags, FROZEN_F, metaClass, NEVER, NIL_F, STAMP_OFFSET, TAINTED_F, UNDEF, VAR_TABLE_OFFSET, varTable, varTableStampFields inherited from interface org.jruby.runtime.builtin.IRubyObject
NULL_ARRAY -
Constructor Summary
ConstructorsConstructorDescriptionProxyMethodImpl(Ruby runtime, JavaProxyClass clazz, Method method, Method superMethod) -
Method Summary
Modifier and TypeMethodDescriptionDeprecated.argument_types(ThreadContext context) arity()Deprecated.arity(ThreadContext context) static RubyClasscreateJavaProxyMethodClass(ThreadContext context, RubyClass Object, RubyModule Java) do_invoke(IRubyObject[] args) Deprecated.do_invoke(ThreadContext context, IRubyObject[] args) booleanThis override does not do a "checked" dispatch.final intgetArity()final JavaProxyClassfinal Class<?>[]intgetName()final Class<?>[]final Class<?> getState()get state (cache target callable?) in the proxy methodinthashCode()This override does not do "checked" dispatch since Object usually has #hash defined.booleanis it possible to call the super method?inspect()Deprecated.inspect(ThreadContext context) Returns a string containing a human-readable representation of obj.final booleanfinal booleanname()Deprecated.voidstore state (cache target callable?) in the proxy methodsuper_p()Deprecated.super_p(ThreadContext context) toString()The default toString method is just a wrapper that calls the Ruby "to_s" method.Methods inherited from class org.jruby.javasupport.proxy.JavaProxyReflectionObject
aref, aref, aset, aset, hash, is_java_proxy, is_java_proxy, java_class, java_class, java_type, java_type, length, length, op_eqq, op_equal, registerRubyMethods, to_sMethods inherited from class org.jruby.RubyObject
attachToObjectSpace, callInit, callInit, callInit, callInit, callInit, callInit, callInit, callInit, callInit, callInit, dig, dig1, dig2, eqlInternal, equalInternal, finishObjectClass, getNativeClassIndex, inspect, puts, toRubyStringMethods inherited from class org.jruby.RubyBasicObject
__id__, addFinalizer, addFinalizer, anyToString, asJavaString, asString, callMethod, callMethod, callMethod, callMethod, callMethod, callMethod, callMethod, checkArrayType, checkCallMethod, checkCallMethod, checkFrozen, checkStringType, cloneSetup, compareTo, convertToArray, convertToFloat, convertToHash, convertToInteger, convertToInteger, convertToString, copyInstanceVariablesInto, copySpecialInstanceVariables, dataGetStruct, dataWrapStruct, decode, display, dup, dupFinalizer, dupSetup, ensureInstanceVariablesSettable, eql, eql_p, eql_p, equal_p, evalUnder, extend, finishBasicObjectClass, forEachInstanceVariable, forEachInstanceVariableName, freeze, frozen_p, getCurrentContext, getFFIHandle, getFlag, getInstanceEvalClass, getInstanceEvalClass, getInstanceVariable, getInstanceVariableList, getInstanceVariableNameList, getInstanceVariables, getInternalVariable, getInternalVariables, getJavaClass, getMarshalVariableList, getMetaClass, getMetaClass, getObjectId, getRuntime, getSingletonClass, getSingletonClassClone, getSingletonClassCloneAndAttach, getSingletonClassCloneAndAttach, getType, getVariable, getVariableList, getVariableNameList, hash, hashyInspect, hashyInspect, hasInstanceVariable, hasInstanceVariables, hasInternalVariable, hasVariables, id, infectBy, initialize, initialize_copy, initialize_copy, inspectHashCode, instance_eval, instance_eval, instance_eval, instance_eval, instance_eval, instance_exec, instance_of_p, instance_variable_defined_p, instance_variable_get, instance_variable_set, instance_variables, isBuiltin, isClass, isFalse, isFrozen, isImmediate, isModule, isNil, isSpecialConst, isSpecialObject, isTaint, isTrue, kind_of_p, makeMetaClass, makeMetaClass, makeMetaClassBootstrap, method, method, method, method_missing, methods, nil_p, nonFixnumHashCode, nonFixnumHashCode, OBJ_INIT_COPY, objInitCopy, op_cmp, op_match, op_not, op_not_equal, op_not_match, private_methods, protected_methods, public_methods, rbClone, rbClone, rbInspect, remove_instance_variable, removeFinalizers, removeInstanceVariable, removeInternalVariable, respond_to_p, respondsTo, respondsToMissing, respondsToMissing, send, send, send, send, send, setFFIHandle, setFlag, setFrozen, setInstanceVariable, setInternalVariable, setMetaClass, setTaint, setVariable, singleton_method, singleton_method, singleton_method_added, singleton_method_removed, singleton_method_undefined, singleton_methods, singletonClass, specificEval, specificEval, specificEval, specificEval, syncVariables, taint, taint, tainted_p, testFrozen, testFrozen, to_a, to_s, toJava, type, untaint, validateInstanceVariable, variableTableContains, variableTableFetch, variableTableRemove, variableTableStore, variableTableSync, yieldUnder, yieldUnderMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface org.jruby.runtime.builtin.IRubyObject
__id__, addFinalizer, addFinalizer, anyToString, asJavaString, asString, callMethod, callMethod, callMethod, callMethod, checkArrayType, checkCallMethod, checkCallMethod, checkStringType, checkStringType19, convertToArray, convertToFloat, convertToHash, convertToInteger, convertToInteger, convertToString, copySpecialInstanceVariables, dataGetStruct, dataWrapStruct, dup, dup, eql, getInstanceVariables, getInternalVariables, getJavaClass, getMarshalVariableList, getMetaClass, getRuntime, getSingletonClass, getType, getVariable, getVariableList, getVariableNameList, hasVariables, id, infectBy, isClass, isFrozen, isImmediate, isModule, isNil, isSpecialConst, isTaint, isTrue, marshalLiveVariables, op_eqq, op_equal, rbClone, removeFinalizers, respondsTo, respondsToMissing, respondsToMissing, setFrozen, setTaint, setVariable, singletonClass, syncVariables, toJava
-
Constructor Details
-
ProxyMethodImpl
-
-
Method Details
-
createJavaProxyMethodClass
public static RubyClass createJavaProxyMethodClass(ThreadContext context, RubyClass Object, RubyModule Java) -
equals
Description copied from class:RubyObjectThis override does not do a "checked" dispatch.- Overrides:
equalsin classJavaProxyReflectionObject- Parameters:
other- object to compare- Returns:
- true if equals
- See Also:
-
hashCode
public int hashCode()Description copied from class:RubyObjectThis override does not do "checked" dispatch since Object usually has #hash defined.- Overrides:
hashCodein classJavaProxyReflectionObject- Returns:
- the hash code
- See Also:
-
getMethod
-
getSuperMethod
- Specified by:
getSuperMethodin interfaceJavaProxyMethod
-
getModifiers
public int getModifiers()- Specified by:
getModifiersin interfaceJavaProxyMethod
-
getName
- Specified by:
getNamein interfaceJavaProxyMethod
-
getExceptionTypes
- Specified by:
getExceptionTypesin interfaceParameterTypes
-
getParameterTypes
- Specified by:
getParameterTypesin interfaceParameterTypes
-
isVarArgs
public final boolean isVarArgs()- Specified by:
isVarArgsin interfaceParameterTypes
-
hasSuperImplementation
public boolean hasSuperImplementation()Description copied from interface:JavaProxyMethodis it possible to call the super method?- Specified by:
hasSuperImplementationin interfaceJavaProxyMethod
-
invoke
public Object invoke(Object proxy, Object[] args) throws IllegalArgumentException, IllegalAccessException, InvocationTargetException, NoSuchMethodException - Specified by:
invokein interfaceJavaProxyMethod- Parameters:
proxy-args-- Returns:
- Throws:
IllegalArgumentExceptionIllegalAccessExceptionInvocationTargetExceptionNoSuchMethodException- if this ProxyMethod has no super implementation
-
getState
Description copied from interface:JavaProxyMethodget state (cache target callable?) in the proxy method- Specified by:
getStatein interfaceJavaProxyMethod
-
setState
Description copied from interface:JavaProxyMethodstore state (cache target callable?) in the proxy method- Specified by:
setStatein interfaceJavaProxyMethod
-
toString
Description copied from class:RubyObjectThe default toString method is just a wrapper that calls the Ruby "to_s" method.- Overrides:
toStringin classJavaProxyReflectionObject- Returns:
- string representation
-
matches
-
getReturnType
- Specified by:
getReturnTypein interfaceJavaProxyMethod
-
name
Deprecated. -
getDeclaringClass
- Specified by:
getDeclaringClassin interfaceJavaProxyMethod
-
argument_types
Deprecated. -
argument_types
-
super_p
Deprecated. -
super_p
-
arity
Deprecated. -
arity
-
inspect
Deprecated.Description copied from interface:IRubyObjectRubyMethod inspect.- Specified by:
inspectin interfaceIRubyObject- Overrides:
inspectin classRubyBasicObject- Returns:
- String
-
inspect
Description copied from class:RubyBasicObjectReturns a string containing a human-readable representation of obj. If not overridden, uses theto_smethod to generate the string. [ 1, 2, 3..4, 'five' ].inspect #=> "[1, 2, 3..4, \"five\"]" Time.new.inspect #=> "Wed Apr 09 08:54:39 CDT 2003"- Specified by:
inspectin interfaceIRubyObject- Overrides:
inspectin classRubyBasicObject
-
do_invoke
Deprecated.Usedo_invoke(ThreadContext, IRubyObject[])instead.- Parameters:
args-- Returns:
-
do_invoke
-
getArity
public final int getArity()- Specified by:
getArityin interfaceParameterTypes
-
do_invoke(ThreadContext, IRubyObject[])instead.