Module org.jruby.base
Package org.jruby
package org.jruby
-
ClassDescriptionBase type for the two Ruby Method types.Code evaluation typeAn almost entirely useless interface for those objects that we _really_ want to finalize.This class serves as a registry of all bit flags we use on JRuby objects.This class is used to provide an intermediate superclass for modules and classes that include other modules.Deprecated, for removal: This API element is subject to removal in a future version.Deprecated.Use
Maininstead.Deprecated.Flags used by RubyBasicObject descendants.This class is used as an intermediate superclass for Module#prepend.The Ruby object represents the top-level of a JRuby "instance" in a given VM.The Java representation of a Ruby ArgumentError.Implements Enumerator::ArithmeticSequenceRubyArray<T extends IRubyObject>The implementation of the built-in class Array in Ruby.RubyBasicObject is the only implementation of theIRubyObject.Class that keeps track of the finalizers for the object under operation.Implements Enumerator::ChainImplementation of the Comparable module.complex.c as of revision: 20011The Java representation of a Ruby ConcurrencyError.Deprecated.Deprecated.The Ruby built-in class Dir./** The Java representation of a Ruby DomainError.The Java representation of a Ruby EncodingError.The implementation of Ruby's Enumerable module.Implementation of Ruby's Enumerator module.Internal Enumerator::FeedValue class to be shared between enumerator and its next-er Fiber.RubyEnumerator.SizeFn<T extends IRubyObject>"Function" type for java-created enumerators with size.The Java representation of a Ruby EOFError.The Java representation of a Ruby Fatal.The Java representation of a Ruby FiberError.The Ruby File class.Implements File::StatMRI defines the FileTest methods both as module functions on FileTest and as singleton methods on the File class.Implementation of the Integer (Fixnum internal) class.A representation of a float objectThe Java representation of a Ruby FloatDomainError.The Java representation of a Ruby FrozenError.GC (Garbage Collection) Module Note: Since we rely on Java's memory model we can't provide the kind of control over garbage collection that MRI provides.This class initializes global variables and constants.Obligate string-keyed and string-valued hash, used for ENV.A Pseudo-hash whose keys and values are required to be Strings.Implementation of the Hash class.The Java representation of a Ruby IndexError.A structure used to configure new JRuby instances.Implementation of the Integer class.The Java representation of a Ruby Interrupt.The Java representation of a Ruby InterruptedRegexpError.Represents a Ruby IO::TimeoutErrorError as a throwable Java exception.The Java representation of a Ruby IOError.Note: For CVS history, see KernelModule.java.The Java representation of a Ruby LoadError.The Java representation of a Ruby LocalJumpError.Marshal moduleInner class to help with Γ functionsThe RubyMethod class represents a RubyMethod object.Deprecated.Represents a constant value, possibly hidden (private).Deprecated.A wrapper CacheEntryFactory, for delegating cache entry creation along a chain.The Java representation of a Ruby NameError.Nested class whose instances act as thunks reacting to to_str method called from (Exception#to_str, Exception#message) MRI equivalent: rb_cNameErrorMesg, class name: "message", construction method: "!", to_str implementation: "name_err_mesg_to_str" TODO: this class should not be lookupableThe Java representation of a Ruby ArgumentError.The Java representation of a Ruby ArgumentError.The Java representation of a Ruby NoMemoryError.The Java representation of a Ruby NoMethodError.The Java representation of a Ruby NotImplementedError.Base class for all numerical types in ruby.Deprecated.Deprecated.RubyObject represents the implementation of the Object class in Ruby.Implements Enumerator::ProducerImplementation of the Random class.The Java representation of a Ruby RangeError.Ruby Rational impl (MRI: rational.c).The Java representation of a Ruby RegexpError.The Java representation of a Ruby RuntimeError.The Java representation of a Ruby ScriptError.The Java representation of a Ruby SecurityError.The Java representation of a Ruby SignalException.The Java representation of a Ruby StandardError./** The Java representation of a Ruby StopIteration.Implementation of Ruby String class Concurrency: no synchronization is required among readers, but all users must synchronize externally with writers.Encoding aware String construction routines for 1.9An FString is a frozen string that is also deduplicated and cached.Represents a Ruby symbol (e.g.The Java representation of a Ruby SyntaxError.The Java representation of a Ruby SystemCallError.The Java representation of a Ruby SystemExit.The Java representation of a Ruby SystemStackError.Implementation of Ruby'sThreadclass.Deprecated.RubyThread.ReadWrite<Data>Thread statusesRubyThread.Task<Data,Return> RubyThread.Unblocker<Data>The Java representation of a Ruby ThreadError.Implementation of Ruby'sThreadGroupclass.The Time class.The Java representation of a Ruby TypeError.An unbound method representation (e.g.The Java representation of a Ruby UncaughtThrowError.The Java representation of a Ruby ZeroDivisionError.
JarBootstrapMaininstead.