Module org.jruby.base
Package org.jruby.runtime.callsite
package org.jruby.runtime.callsite
-
ClassesClassDescriptionSingle type call siteDeprecated.An interesting callsite in which we will look for monomorphic behavior in case we want to inline.
MonomorphicCallSite