java.lang.Object
org.jruby.RubyBasicObject
org.jruby.RubyObject
org.jruby.RubyArray
org.jruby.RubyArrayNative
org.jruby.specialized.RubyArraySpecialized
org.jruby.specialized.RubyArrayTwoObject
- All Implemented Interfaces:
Serializable,Cloneable,Comparable,Iterable,Collection,List,RandomAccess,SequencedCollection,InstanceVariables,InternalVariables,IRubyObject,CoreObjectType
Two object version of RubyArraySpecialized.
- See Also:
-
Nested Class Summary
Nested classes/interfaces inherited from class org.jruby.RubyArrayNative
RubyArrayNative.ArgumentVisitor, RubyArrayNative.RubyArrayConversionIteratorNested classes/interfaces inherited from class org.jruby.RubyArray
RubyArray.DefaultComparatorNested classes/interfaces inherited from class org.jruby.RubyObject
RubyObject.DataNested classes/interfaces inherited from class org.jruby.RubyBasicObject
RubyBasicObject.Finalizer -
Field Summary
Fields inherited from class org.jruby.specialized.RubyArraySpecialized
MAX_PACKED_SIZEFields inherited from class org.jruby.RubyArrayNative
ARRAY_DEFAULT_SIZE, begin, DEFAULT_INSPECT_STR_SIZE, realLength, valuesFields inherited from class org.jruby.RubyObject
IVAR_INSPECTING_OBJECT_ALLOCATOR, OBJECT_ALLOCATOR, REIFYING_OBJECT_ALLOCATORFields inherited from class org.jruby.RubyBasicObject
ALL_F, BASICOBJECT_ALLOCATOR, ERR_INSECURE_SET_INST_VAR, FALSE_F, flags, FROZEN_F, metaClass, NEVER, NIL_F, STAMP_OFFSET, TAINTED_F, UNDEF, VAR_TABLE_OFFSET, varTable, varTableStampFields inherited from interface org.jruby.runtime.builtin.IRubyObject
NULL_ARRAY -
Constructor Summary
ConstructorsConstructorDescriptionRubyArrayTwoObject(RubyClass otherClass, IRubyObject car, IRubyObject cdr) RubyArrayTwoObject(Ruby runtime, IRubyObject car, IRubyObject cdr) -
Method Summary
Modifier and TypeMethodDescriptionaryDup()rb_ary_dupRubyArray<?> collectArray(ThreadContext context, Block block) Collect the contents of this array after filtering through block, or return a new equivalent array if the block is not given (!isGiven()).voidcopyInto(ThreadContext context, IRubyObject[] target, int start) Copy the values contained in this array into the target array at the specified offset.voidcopyInto(ThreadContext context, IRubyObject[] target, int start, int len) Copy the specified number of values contained in this array into the target array at the specified offset.protected RubyArrayNative<?> final IRubyObjecteltInternal(int index) final IRubyObjecteltInternalSet(int index, IRubyObject value) protected voidfinishUnpack(IRubyObject nil) booleanincludes(ThreadContext context, IRubyObject item) intprotected IRubyObjectinspectAry(ThreadContext context) inspect_aryprotected IRubyObjectinternalRotate(ThreadContext context, int cnt) protected IRubyObjectinternalRotateBang(ThreadContext context, int cnt) protected RubyArrayNative<?> rb_ary_make_sharedop_plus(ThreadContext context, IRubyObject obj) rb_ary_plusrb_clear(ThreadContext context) rb_ary_clearreplace(ThreadContext context, IRubyObject orig) rb_ary_replacereverse_bang(ThreadContext context) rb_ary_reverse_bangprotected RubyArray<?> protected IRubyObjectsortInternal(ThreadContext context, boolean honorOverride) protected IRubyObjectsortInternal(ThreadContext context, Block block) protected voidstoreInternal(int index, IRubyObject value) Deprecated.protected voidstoreInternal(ThreadContext context, int index, IRubyObject value) toJavaArray(ThreadContext context) Return a Java array copy of the elements contained in this Array.uniq(ThreadContext context) rb_ary_uniqMethods inherited from class org.jruby.specialized.RubyArraySpecialized
packed, unpackMethods inherited from class org.jruby.RubyArrayNative
add, add, add, addAll, addAll, all_p, all_p, all_pCommon, any_p, any_p, any_pCommon, append, aref, aref, aryAppend, aryToAry, aset, aset, assoc, at, bsearch, bsearch_index, clear, collect, collect_bang, collectBang, collectEnum, combination, compact, compact_bang, compare, compareFixnums, compareOthers, concat, concat, concat, contains, containsAll, count, count, create, cycle, cycle, delete, delete_at, delete_at, delete_if, deleteIf, detectCommon, difference, dig, dig, dig, dig, drop, drop_while, dup, each, each_index, each_slice, eachIndex, eachSlice, elt, eltOk, eltSetOk, eltSetOk, empty_p, entry, entry, eql, equals, fetch, fetch, fetch_values, fill, fill, fill, fill, fillCommon, fillCommon, find, find_index, find_index, first, first, flatten, flatten, flatten, flatten_bang, flatten_bang, get, getJavaClass, getLength, hash, include_p, includesByEql, index, index, index, initialize, initialize, initialize, initialize_copy, initializeCommon, insert, insert, insert, insert, inspect, intersect_p, intersection, isEmpty, isSharedJavaArray, iterator, join, join, joinStrings, keep_if, last, last, lastIndexOf, length, listIterator, listIterator, makeHash, makeHash, map, map_bang, max, max, min, min, minmax, modify, modify, modifyCheck, modifyCheck, newArray, newArray, newArray, newArray, newArray, newArray, newArray, newArray, newArray, newArray, newArrayLight, newArrayLight, newArrayLight, newArrayLight, newArrayLight, newArrayLight, newArrayLight, newArrayMayCopy, newArrayMayCopy, newArrayMayCopy, newArrayNoCopy, newArrayNoCopy, newArrayNoCopy, newArrayNoCopyLight, newBlankArray, newEmptyArray, newEmptyArray, newSharedArray, nitems, none_p, none_p, none_pCommon, one_p, one_p, one_pCommon, op_and, op_cmp, op_diff, op_equal, op_or, op_times, pack, pack, permutation, permutation, pop, pop, product, product, push, push, rassoc, rbCollect, reject, reject_bang, rejectBang, rejectCommon, remove, remove, removeAll, repeated_permutation, repeatedCombination, retainAll, reverse, reverse_each, reverseEach, rfind, rfind, rindex, rindex, rindex, rotate, rotate, rotate_bang, rotate_bang, rubyStream, safeArraySet, sample, sample, sample, select, select_bang, selectCommon, set, shift, shift, shuffle, shuffle, shuffle_bang, shuffle_bang, size, size, slice_bang, slice_bang, sort, sort_bang, sort_by_bang, store, store, subList, subseq, subseq_step, subseqLight, sum, sum, sumCommon, take, take_while, to_a, to_h, to_s, toArray, toArray, toJava, toJavaArrayMaybeUnsafe, toJavaArrayUnsafe, transpose, try_convert, union, unionInternal, uniq, uniq_bang, uniq_bang, unshift, unshift, unshift, values_at, zipMethods inherited from class org.jruby.RubyArray
append, aref, aref, aryAppend, aset, aset, aset, at, checkArrayType, checkLength, checkLength, compact, compact_bang, convertToArray, copyInto, copyInto, create, createArrayClass, deconstruct, delete_at, delete_at, empty_p, fetch, first, first, first, getList, getNativeClassIndex, indexes, indexes, insert, insert, insert, join19, join19, last, last, last, length, marshalTo, marshalTo, marshalTo, newArray, newBlankArray, nitems, op_and, op_diff, op_or, op_plus, push, push, push_m, rb_clear, replace, reverse, reverse_bang, slice_bang, slice_bang, slice_bang, to_ary, to_ary, toJavaArray, transpose, unmarshalFrom, unmarshalFrom, unshift, unshift, unshift, values_atMethods inherited from class org.jruby.RubyObject
attachToObjectSpace, callInit, callInit, callInit, callInit, callInit, callInit, callInit, callInit, callInit, callInit, dig, dig1, dig2, eqlInternal, equalInternal, finishObjectClass, hashCode, inspect, op_eqq, puts, toRubyString, toStringMethods inherited from class org.jruby.RubyBasicObject
__id__, addFinalizer, addFinalizer, anyToString, asJavaString, asString, callMethod, callMethod, callMethod, callMethod, callMethod, callMethod, callMethod, checkCallMethod, checkCallMethod, checkFrozen, checkStringType, cloneSetup, compareTo, convertToFloat, convertToHash, convertToInteger, convertToInteger, convertToString, copyInstanceVariablesInto, copySpecialInstanceVariables, dataGetStruct, dataWrapStruct, decode, display, dupFinalizer, dupSetup, ensureInstanceVariablesSettable, eql, eql_p, eql_p, equal_p, evalUnder, extend, finishBasicObjectClass, forEachInstanceVariable, forEachInstanceVariableName, freeze, frozen_p, getCurrentContext, getFFIHandle, getFlag, getInstanceEvalClass, getInstanceEvalClass, getInstanceVariable, getInstanceVariableList, getInstanceVariableNameList, getInstanceVariables, getInternalVariable, getInternalVariables, getMarshalVariableList, getMetaClass, getMetaClass, getObjectId, getRuntime, getSingletonClass, getSingletonClassClone, getSingletonClassCloneAndAttach, getSingletonClassCloneAndAttach, getType, getVariable, getVariableList, getVariableNameList, hash, hashyInspect, hashyInspect, hasInstanceVariable, hasInstanceVariables, hasInternalVariable, hasVariables, id, infectBy, initialize, initialize_copy, inspect, inspectHashCode, instance_eval, instance_eval, instance_eval, instance_eval, instance_eval, instance_exec, instance_of_p, instance_variable_defined_p, instance_variable_get, instance_variable_set, instance_variables, isBuiltin, isClass, isFalse, isFrozen, isImmediate, isModule, isNil, isSpecialConst, isSpecialObject, isTaint, isTrue, kind_of_p, makeMetaClass, makeMetaClass, makeMetaClassBootstrap, method, method, method, method_missing, methods, nil_p, nonFixnumHashCode, nonFixnumHashCode, OBJ_INIT_COPY, objInitCopy, op_match, op_not, op_not_equal, op_not_match, private_methods, protected_methods, public_methods, rbClone, rbClone, rbInspect, remove_instance_variable, removeFinalizers, removeInstanceVariable, removeInternalVariable, respond_to_p, respondsTo, respondsToMissing, respondsToMissing, send, send, send, send, send, setFFIHandle, setFlag, setFrozen, setInstanceVariable, setInternalVariable, setMetaClass, setTaint, setVariable, singleton_method, singleton_method, singleton_method_added, singleton_method_removed, singleton_method_undefined, singleton_methods, singletonClass, specificEval, specificEval, specificEval, specificEval, syncVariables, taint, taint, tainted_p, testFrozen, testFrozen, to_s, type, untaint, validateInstanceVariable, variableTableContains, variableTableFetch, variableTableRemove, variableTableStore, variableTableSync, yieldUnder, yieldUnderMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface java.util.Collection
parallelStream, removeIf, stream, toArrayMethods inherited from interface org.jruby.runtime.builtin.IRubyObject
checkStringType19, dup, marshalLiveVariablesMethods inherited from interface java.util.List
addFirst, addLast, getFirst, getLast, hashCode, removeFirst, removeLast, replaceAll, reversed, sort, spliterator
-
Constructor Details
-
RubyArrayTwoObject
-
RubyArrayTwoObject
-
-
Method Details
-
eltInternal
- Overrides:
eltInternalin classRubyArrayNative
-
eltInternalSet
- Overrides:
eltInternalSetin classRubyArrayNative
-
finishUnpack
- Specified by:
finishUnpackin classRubyArraySpecialized
-
aryDup
Description copied from class:RubyArrayNativerb_ary_dup- Overrides:
aryDupin classRubyArrayNative
-
rb_clear
Description copied from class:RubyArrayNativerb_ary_clear- Overrides:
rb_clearin classRubyArrayNative
-
copyInto
Description copied from class:RubyArrayNativeCopy the values contained in this array into the target array at the specified offset. It is expected that the target array is large enough to hold all necessary values.- Overrides:
copyIntoin classRubyArrayNative
-
copyInto
Description copied from class:RubyArrayNativeCopy the specified number of values contained in this array into the target array at the specified offset. It is expected that the target array is large enough to hold all necessary values.- Overrides:
copyIntoin classRubyArrayNative
-
dupImpl
- Overrides:
dupImplin classRubyArrayNative
-
includes
- Overrides:
includesin classRubyArrayNative
-
indexOf
- Specified by:
indexOfin interfaceList- Overrides:
indexOfin classRubyArrayNative
-
inspectAry
Description copied from class:RubyArrayNativeinspect_ary- Overrides:
inspectAryin classRubyArrayNative
-
internalRotate
- Overrides:
internalRotatein classRubyArrayNative
-
internalRotateBang
- Overrides:
internalRotateBangin classRubyArrayNative
-
op_plus
Description copied from class:RubyArrayNativerb_ary_plus- Overrides:
op_plusin classRubyArrayNative
-
replace
Description copied from class:RubyArrayNativerb_ary_replace- Overrides:
replacein classRubyArrayNative
-
reverse_bang
Description copied from class:RubyArrayNativerb_ary_reverse_bang- Overrides:
reverse_bangin classRubyArrayNative
-
safeReverse
- Overrides:
safeReversein classRubyArrayNative
-
sortInternal
- Overrides:
sortInternalin classRubyArrayNative
-
sortInternal
- Overrides:
sortInternalin classRubyArrayNative
-
storeInternal
Deprecated. -
storeInternal
- Overrides:
storeInternalin classRubyArrayNative
-
subseq
- Overrides:
subseqin classRubyArrayNative
-
toJavaArray
Description copied from class:RubyArrayNativeReturn a Java array copy of the elements contained in this Array. This version always creates a new Java array that is exactly the length of the Array's elements.- Overrides:
toJavaArrayin classRubyArrayNative- Returns:
- a Java array with exactly the size and contents of this RubyArray's elements
-
uniq
Description copied from class:RubyArrayNativerb_ary_uniq- Overrides:
uniqin classRubyArrayNative
-
collectArray
Description copied from class:RubyArrayNativeCollect the contents of this array after filtering through block, or return a new equivalent array if the block is not given (!isGiven()).- Overrides:
collectArrayin classRubyArrayNative- Parameters:
context- the current contextblock- a block for filtering or NULL_BLOCK- Returns:
- an array of the filtered or unfiltered results
-