Enum Constant Summary
Enum Constants
Method Summary
All Methods Static Methods Instance Methods Concrete Methods
int
org.jcodings.Encoding
Returns the enum constant of this class with the specified name.
Returns an array containing the constants of this enum class, in
the order they are declared.
Enum Constant Details
NIL
public static final KCode NIL
NONE
public static final KCode NONE
UTF8
public static final KCode UTF8
SJIS
public static final KCode SJIS
EUC
public static final KCode EUC
Method Details
values
public static KCode [] values ()
Returns an array containing the constants of this enum class, in
the order they are declared.
Returns:
an array containing the constants of this enum class, in the order they are declared
valueOf
Returns the enum constant of this class with the specified name.
The string must match exactly an identifier used to declare an
enum constant in this class. (Extraneous whitespace characters are
not permitted.)
Parameters:
name - the name of the enum constant to be returned.
Returns:
the enum constant with the specified name
Throws:
IllegalArgumentException - if this enum class has no constant with the specified name
NullPointerException - if the argument is null
fromBits
public static KCode fromBits (int bits)
getEncoding
public org.jcodings.Encoding getEncoding ()