Uses of Interface
org.jruby.util.ClassDefiningClassLoader
Packages that use ClassDefiningClassLoader
Package
Description
-
Uses of ClassDefiningClassLoader in org.jruby.compiler.util
Methods in org.jruby.compiler.util with parameters of type ClassDefiningClassLoaderModifier and TypeMethodDescriptionstatic HandleFactory.HandleHandleFactory.createHandle(ClassDefiningClassLoader classLoader, Method method) static ClassHandleFactory.createHandleClass(ClassDefiningClassLoader classLoader, Method method, String name) -
Uses of ClassDefiningClassLoader in org.jruby.ir
Methods in org.jruby.ir with parameters of type ClassDefiningClassLoaderModifier and TypeMethodDescriptionprotected ScriptAndCodeCompiler.execute(ThreadContext context, IRScriptBody scope, ClassDefiningClassLoader classLoader) -
Uses of ClassDefiningClassLoader in org.jruby.ir.targets
Methods in org.jruby.ir.targets with parameters of type ClassDefiningClassLoaderModifier and TypeMethodDescriptionJVMVisitor.compile(IRScope scope, ClassDefiningClassLoader jrubyClassLoader) JVMVisitor.defineFromBytecode(IRScope scope, byte[] code, ClassDefiningClassLoader jrubyClassLoader) Define a scope's compiled class from bytecode.JVMVisitor.defineFromBytecode(IRScope scope, byte[] code, ClassDefiningClassLoader jrubyClassLoader, boolean setScopes) JVMVisitor.defineScriptFromBytecode(IRScope scope, byte[] code, ClassDefiningClassLoader jrubyClassLoader) Define a class from a top-level script's bytecode. -
Uses of ClassDefiningClassLoader in org.jruby.java.codegen
Methods in org.jruby.java.codegen with parameters of type ClassDefiningClassLoaderModifier and TypeMethodDescriptionstatic ClassRealClassGenerator.createOldStyleImplClass(Class[] superTypes, RubyClass rubyClass, Ruby ruby, String name, ClassDefiningClassLoader classLoader) static ClassRealClassGenerator.defineOldStyleImplClass(Ruby ruby, String name, String[] superTypeNames, Map<String, List<Method>> simpleToAll, ClassDefiningClassLoader loader) This variation on defineImplClass uses all the classic type coercion logic for passing args and returning results. -
Uses of ClassDefiningClassLoader in org.jruby.runtime.scope
Methods in org.jruby.runtime.scope with parameters of type ClassDefiningClassLoaderModifier and TypeMethodDescriptionstatic ClassDynamicScopeGenerator.generateClassForSize(ClassDefiningClassLoader cdcl, int size) -
Uses of ClassDefiningClassLoader in org.jruby.util
Classes in org.jruby.util that implement ClassDefiningClassLoaderModifier and TypeClassDescriptionclassclassthis classloader will be populated dynamically in the following ways:JRuby.runtime.jruby_class_loader.add_url( java.net.URL.new( "file:my.jar" )$CLASSPATH << 'path/to/class/or/resources'require 'some.jar'load 'some.jar'so it is the classloader for ALL the jars used by gems.classclassRepresents a class loader designed to load exactly one class.class