java.lang.Object
org.jruby.util.collections.ClassValue<T>
org.jruby.util.collections.MapBasedClassValue<T>
- Type Parameters:
T- type
A simple Map-based cache of proxies.
-
Nested Class Summary
Nested classes/interfaces inherited from class org.jruby.util.collections.ClassValue
ClassValue.Type -
Field Summary
Fields inherited from class org.jruby.util.collections.ClassValue
calculator -
Constructor Summary
Constructors -
Method Summary
Methods inherited from class org.jruby.util.collections.ClassValue
newInstance
-
Constructor Details
-
MapBasedClassValue
-
-
Method Details
-
get
- Specified by:
getin classClassValue<T>
-
clear
public void clear()Description copied from class:ClassValueMake a best effort to clear all references. Best effort here is sometimes not easily achievable, if for example values are opaquely contained in aClassValueinstance that does not directly support global clearing.- Overrides:
clearin classClassValue<T>
-