java.lang.Object
org.jruby.RubyBasicObject
org.jruby.RubyObject
org.jruby.RubyArray
org.jruby.RubyArrayNative
org.jruby.util.collections.StringArraySet
- All Implemented Interfaces:
Serializable,Cloneable,Comparable,Iterable,Collection,List,RandomAccess,SequencedCollection,InstanceVariables,InternalVariables,IRubyObject,CoreObjectType
An RubyArray that maintains an O(1) Set for fast include? operations.
- See Also:
-
Nested Class Summary
Nested classes/interfaces inherited from class org.jruby.RubyArrayNative
RubyArrayNative.ArgumentVisitor, RubyArrayNative.RubyArrayConversionIteratorNested classes/interfaces inherited from class org.jruby.RubyArray
RubyArray.DefaultComparatorNested classes/interfaces inherited from class org.jruby.RubyObject
RubyObject.DataNested classes/interfaces inherited from class org.jruby.RubyBasicObject
RubyBasicObject.Finalizer -
Field Summary
Fields inherited from class org.jruby.RubyArrayNative
ARRAY_DEFAULT_SIZE, begin, DEFAULT_INSPECT_STR_SIZE, realLength, valuesFields inherited from class org.jruby.RubyObject
IVAR_INSPECTING_OBJECT_ALLOCATOR, OBJECT_ALLOCATOR, REIFYING_OBJECT_ALLOCATORFields inherited from class org.jruby.RubyBasicObject
ALL_F, BASICOBJECT_ALLOCATOR, ERR_INSECURE_SET_INST_VAR, FALSE_F, flags, FROZEN_F, metaClass, NEVER, NIL_F, STAMP_OFFSET, TAINTED_F, UNDEF, VAR_TABLE_OFFSET, varTable, varTableStampFields inherited from interface org.jruby.runtime.builtin.IRubyObject
NULL_ARRAY -
Constructor Summary
Constructors -
Method Summary
Modifier and TypeMethodDescriptionappend(ThreadContext context, IRubyObject item) rb_ary_push - specialized rb_ary_storefinal voidappendString(Ruby runtime, String element) aset(ThreadContext context, IRubyObject arg0, IRubyObject arg1) aset(ThreadContext context, IRubyObject arg0, IRubyObject arg1, IRubyObject arg2) rb_ary_asetcollectBang(ThreadContext context, Block block) rb_ary_collect_bangcompact_bang(ThreadContext context) rb_ary_compact_bangfinal booleancontainsString(String element) delete(ThreadContext context, IRubyObject item, Block block) rb_ary_deletedelete_if(ThreadContext context, Block block) final voiddeleteString(ThreadContext context, String element) drop(ThreadContext context, IRubyObject n) rb_ary_takedrop_while(ThreadContext context, Block block) rb_ary_take_whileflatten_bang(ThreadContext context) flatten_bang(ThreadContext context, IRubyObject arg) final RubyBooleaninclude_p(ThreadContext context, IRubyObject item) rb_ary_includesinsert()insert(ThreadContext context, IRubyObject arg) rb_ary_insertinsert(ThreadContext context, IRubyObject[] args) insert(ThreadContext context, IRubyObject arg1, IRubyObject arg2) pop(ThreadContext context) rb_ary_poppop(ThreadContext context, IRubyObject num) push(ThreadContext context, IRubyObject item) push(ThreadContext context, IRubyObject[] items) rb_clear(ThreadContext context) rb_ary_clearrejectBang(ThreadContext context, Block block) replace(ThreadContext context, IRubyObject orig) rb_ary_replaceselect_bang(ThreadContext context, Block block) shift(ThreadContext context) rb_ary_shiftshift(ThreadContext context, IRubyObject num) slice_bang(ThreadContext context, IRubyObject arg0) rb_ary_slice_bangslice_bang(ThreadContext context, IRubyObject arg0, IRubyObject arg1) rb_ary_slice_bangunshift(ThreadContext context) unshift(ThreadContext context, IRubyObject item) rb_ary_unshiftunshift(ThreadContext context, IRubyObject[] items) Methods inherited from class org.jruby.RubyArrayNative
add, add, add, addAll, addAll, all_p, all_p, all_pCommon, any_p, any_p, any_pCommon, aref, aref, aryAppend, aryDup, aryToAry, assoc, at, bsearch, bsearch_index, clear, collect, collect_bang, collectArray, collectEnum, combination, compact, compare, compareFixnums, compareOthers, concat, concat, concat, contains, containsAll, copyInto, copyInto, count, count, create, cycle, cycle, delete_at, delete_at, deleteIf, detectCommon, difference, dig, dig, dig, dig, dup, dupImpl, each, each_index, each_slice, eachIndex, eachSlice, elt, eltInternal, eltInternalSet, eltOk, eltSetOk, eltSetOk, empty_p, entry, entry, eql, equals, fetch, fetch, fetch_values, fill, fill, fill, fill, fillCommon, fillCommon, find, find_index, find_index, first, first, flatten, flatten, flatten, get, getJavaClass, getLength, hash, includes, includesByEql, index, index, index, indexOf, initialize, initialize, initialize, initialize_copy, initializeCommon, inspect, inspectAry, internalRotate, internalRotateBang, intersect_p, intersection, isEmpty, isSharedJavaArray, iterator, join, join, joinStrings, keep_if, last, last, lastIndexOf, length, listIterator, listIterator, makeHash, makeHash, makeShared, map, map_bang, max, max, min, min, minmax, modify, modify, modifyCheck, modifyCheck, newArray, newArray, newArray, newArray, newArray, newArray, newArray, newArray, newArray, newArray, newArrayLight, newArrayLight, newArrayLight, newArrayLight, newArrayLight, newArrayLight, newArrayLight, newArrayMayCopy, newArrayMayCopy, newArrayMayCopy, newArrayNoCopy, newArrayNoCopy, newArrayNoCopy, newArrayNoCopyLight, newBlankArray, newEmptyArray, newEmptyArray, newSharedArray, nitems, none_p, none_p, none_pCommon, one_p, one_p, one_pCommon, op_and, op_cmp, op_diff, op_equal, op_or, op_plus, op_times, pack, pack, permutation, permutation, product, product, rassoc, rbCollect, reject, reject_bang, rejectCommon, remove, remove, removeAll, repeated_permutation, repeatedCombination, retainAll, reverse, reverse_bang, reverse_each, reverseEach, rfind, rfind, rindex, rindex, rindex, rotate, rotate, rotate_bang, rotate_bang, rubyStream, safeArraySet, safeReverse, sample, sample, sample, select, selectCommon, set, shuffle, shuffle, shuffle_bang, shuffle_bang, size, size, sort, sort_bang, sort_by_bang, sortInternal, sortInternal, store, store, storeInternal, subList, subseq, subseq, subseq_step, subseqLight, sum, sum, sumCommon, take, take_while, to_a, to_h, to_s, toArray, toArray, toJava, toJavaArray, toJavaArrayMaybeUnsafe, toJavaArrayUnsafe, transpose, try_convert, union, unionInternal, uniq, uniq, uniq_bang, uniq_bang, unpack, values_at, zipMethods inherited from class org.jruby.RubyArray
append, aref, aref, aryAppend, aset, aset, aset, at, checkArrayType, checkLength, checkLength, compact, compact_bang, convertToArray, copyInto, copyInto, create, createArrayClass, deconstruct, delete_at, delete_at, empty_p, fetch, first, first, first, getList, getNativeClassIndex, indexes, indexes, insert, insert, insert, join19, join19, last, last, last, length, marshalTo, marshalTo, marshalTo, newArray, newBlankArray, nitems, op_and, op_diff, op_or, op_plus, push, push, push_m, rb_clear, replace, reverse, reverse_bang, slice_bang, slice_bang, slice_bang, to_ary, to_ary, toJavaArray, transpose, unmarshalFrom, unmarshalFrom, unshift, unshift, unshift, values_atMethods inherited from class org.jruby.RubyObject
attachToObjectSpace, callInit, callInit, callInit, callInit, callInit, callInit, callInit, callInit, callInit, callInit, dig, dig1, dig2, eqlInternal, equalInternal, finishObjectClass, hashCode, inspect, op_eqq, puts, toRubyString, toStringMethods inherited from class org.jruby.RubyBasicObject
__id__, addFinalizer, addFinalizer, anyToString, asJavaString, asString, callMethod, callMethod, callMethod, callMethod, callMethod, callMethod, callMethod, checkCallMethod, checkCallMethod, checkFrozen, checkStringType, cloneSetup, compareTo, convertToFloat, convertToHash, convertToInteger, convertToInteger, convertToString, copyInstanceVariablesInto, copySpecialInstanceVariables, dataGetStruct, dataWrapStruct, decode, display, dupFinalizer, dupSetup, ensureInstanceVariablesSettable, eql, eql_p, eql_p, equal_p, evalUnder, extend, finishBasicObjectClass, forEachInstanceVariable, forEachInstanceVariableName, freeze, frozen_p, getCurrentContext, getFFIHandle, getFlag, getInstanceEvalClass, getInstanceEvalClass, getInstanceVariable, getInstanceVariableList, getInstanceVariableNameList, getInstanceVariables, getInternalVariable, getInternalVariables, getMarshalVariableList, getMetaClass, getMetaClass, getObjectId, getRuntime, getSingletonClass, getSingletonClassClone, getSingletonClassCloneAndAttach, getSingletonClassCloneAndAttach, getType, getVariable, getVariableList, getVariableNameList, hash, hashyInspect, hashyInspect, hasInstanceVariable, hasInstanceVariables, hasInternalVariable, hasVariables, id, infectBy, initialize, initialize_copy, inspect, inspectHashCode, instance_eval, instance_eval, instance_eval, instance_eval, instance_eval, instance_exec, instance_of_p, instance_variable_defined_p, instance_variable_get, instance_variable_set, instance_variables, isBuiltin, isClass, isFalse, isFrozen, isImmediate, isModule, isNil, isSpecialConst, isSpecialObject, isTaint, isTrue, kind_of_p, makeMetaClass, makeMetaClass, makeMetaClassBootstrap, method, method, method, method_missing, methods, nil_p, nonFixnumHashCode, nonFixnumHashCode, OBJ_INIT_COPY, objInitCopy, op_match, op_not, op_not_equal, op_not_match, private_methods, protected_methods, public_methods, rbClone, rbClone, rbInspect, remove_instance_variable, removeFinalizers, removeInstanceVariable, removeInternalVariable, respond_to_p, respondsTo, respondsToMissing, respondsToMissing, send, send, send, send, send, setFFIHandle, setFlag, setFrozen, setInstanceVariable, setInternalVariable, setMetaClass, setTaint, setVariable, singleton_method, singleton_method, singleton_method_added, singleton_method_removed, singleton_method_undefined, singleton_methods, singletonClass, specificEval, specificEval, specificEval, specificEval, syncVariables, taint, taint, tainted_p, testFrozen, testFrozen, to_s, type, untaint, validateInstanceVariable, variableTableContains, variableTableFetch, variableTableRemove, variableTableStore, variableTableSync, yieldUnder, yieldUnderMethods inherited from class java.lang.Object
clone, finalize, getClass, notify, notifyAll, wait, wait, waitMethods inherited from interface java.util.Collection
parallelStream, removeIf, stream, toArrayMethods inherited from interface org.jruby.runtime.builtin.IRubyObject
checkStringType19, dup, marshalLiveVariablesMethods inherited from interface java.util.List
addFirst, addLast, getFirst, getLast, hashCode, removeFirst, removeLast, replaceAll, reversed, sort, spliterator
-
Constructor Details
-
StringArraySet
-
-
Method Details
-
appendString
-
append
Description copied from class:RubyArrayNativerb_ary_push - specialized rb_ary_store- Overrides:
appendin classRubyArrayNative
-
rb_clear
Description copied from class:RubyArrayNativerb_ary_clear- Overrides:
rb_clearin classRubyArrayNative
-
deleteString
-
delete
Description copied from class:RubyArrayNativerb_ary_delete- Overrides:
deletein classRubyArrayNative
-
delete_if
- Overrides:
delete_ifin classRubyArrayNative
-
include_p
Description copied from class:RubyArrayNativerb_ary_includes- Overrides:
include_pin classRubyArrayNative
-
replace
Description copied from class:RubyArrayNativerb_ary_replace- Overrides:
replacein classRubyArrayNative
-
aset
- Overrides:
asetin classRubyArrayNative
-
aset
public IRubyObject aset(ThreadContext context, IRubyObject arg0, IRubyObject arg1, IRubyObject arg2) Description copied from class:RubyArrayNativerb_ary_aset- Overrides:
asetin classRubyArrayNative
-
collectBang
Description copied from class:RubyArrayNativerb_ary_collect_bang- Overrides:
collectBangin classRubyArrayNative
-
compact_bang
Description copied from class:RubyArrayNativerb_ary_compact_bang- Overrides:
compact_bangin classRubyArrayNative
-
drop
Description copied from class:RubyArrayNativerb_ary_take- Overrides:
dropin classRubyArrayNative
-
drop_while
Description copied from class:RubyArrayNativerb_ary_take_while- Overrides:
drop_whilein classRubyArrayNative
-
flatten_bang
- Overrides:
flatten_bangin classRubyArrayNative
-
flatten_bang
- Overrides:
flatten_bangin classRubyArrayNative
-
insert
- Overrides:
insertin classRubyArrayNative
-
insert
Description copied from class:RubyArrayNativerb_ary_insert- Overrides:
insertin classRubyArrayNative
-
insert
- Overrides:
insertin classRubyArrayNative
-
insert
- Overrides:
insertin classRubyArrayNative
-
pop
Description copied from class:RubyArrayNativerb_ary_pop- Overrides:
popin classRubyArrayNative
-
pop
- Overrides:
popin classRubyArrayNative
-
push
- Overrides:
pushin classRubyArrayNative
-
push
- Overrides:
pushin classRubyArrayNative
-
rejectBang
- Overrides:
rejectBangin classRubyArrayNative
-
select_bang
- Overrides:
select_bangin classRubyArrayNative
-
shift
Description copied from class:RubyArrayNativerb_ary_shift- Overrides:
shiftin classRubyArrayNative
-
shift
- Overrides:
shiftin classRubyArrayNative
-
slice_bang
Description copied from class:RubyArrayNativerb_ary_slice_bang- Overrides:
slice_bangin classRubyArrayNative
-
slice_bang
Description copied from class:RubyArrayNativerb_ary_slice_bang- Overrides:
slice_bangin classRubyArrayNative
-
unshift
- Overrides:
unshiftin classRubyArrayNative
-
unshift
Description copied from class:RubyArrayNativerb_ary_unshift- Overrides:
unshiftin classRubyArrayNative
-
unshift
- Overrides:
unshiftin classRubyArrayNative
-
containsString
-