Module org.jruby.base
Package org.jruby.util.collections
package org.jruby.util.collections
-
ClassDescriptionClassValue<T>Represents a cache or other mechanism for getting the Ruby-level proxy classes for a given Java class.Calculate a value based on an incoming class.A hash table with weak keys, full concurrency of retrievals, and adjustable expected concurrency for updates.DoubleObject<T,
U> A carrier object with two fieldsHashMapInt<V>IntHashMap<V>A simple Map-based cache of proxies.NonBlockingHashMapLong<TypeV>A lock-free alternate implementation ofConcurrentHashMapwith primitive long keys, better scaling properties and generally lower costs.A carrier object with a single booleanA carrier object with a single doubleA carrier object with a single intA carrier object with a single longSingleObject<T>A carrier object with a single fieldAn RubyArray that maintains an O(1) Set for fast include? operations.WeakHashSet<T>A simple set that uses weak references to ensure that its elements can be garbage collected.WeakValuedIdentityMap<Key,Value> Map-like that holds its values weakly and uses object identity for keys.WeakValuedMap<Key,Value> Map-like that holds its values weakly (backed by a concurrent hash map).WeakValuedMap.KeyedReference<Key,Value>