Uses of Class
org.jruby.util.io.ModeFlags
Packages that use ModeFlags
-
Uses of ModeFlags in org.jruby
Modifier and TypeMethodDescriptionstatic ModeFlagsRubyIO.newModeFlags(Ruby runtime, int mode) static ModeFlagsRubyIO.newModeFlags(Ruby runtime, long mode) static ModeFlagsRubyIO.newModeFlags(Ruby runtime, String mode) Modifier and TypeMethodDescriptionstatic IOOptionsRubyIO.newIOOptions(Ruby runtime, ModeFlags modeFlags) -
Uses of ModeFlags in org.jruby.util
Methods in org.jruby.util with parameters of type ModeFlagsModifier and TypeMethodDescriptiondefault ChannelFileResource.openChannel(ModeFlags flags, int perm) Deprecated.static ShellLauncher.POpenProcessShellLauncher.popen(Ruby runtime, IRubyObject[] strings, Map env, ModeFlags modes) static ShellLauncher.POpenProcessShellLauncher.popen(Ruby runtime, IRubyObject string, Map env, ModeFlags modes) static ShellLauncher.POpenProcessShellLauncher.popen(Ruby runtime, IRubyObject string, ModeFlags modes) Constructors in org.jruby.util with parameters of type ModeFlags -
Uses of ModeFlags in org.jruby.util.io
Methods in org.jruby.util.io that return ModeFlagsModifier and TypeMethodDescriptionstatic ModeFlagsModeFlags.createModeFlags(int oflags) IOOptions.getModeFlags()Methods in org.jruby.util.io with parameters of type ModeFlagsModifier and TypeMethodDescriptionbooleanModeFlags.isSubsetOf(ModeFlags superset) Check whether the target set of flags is a superset of this one; used to ensure that a file is not re-opened with more privileges than it already had.voidIOOptions.setModeFlags(ModeFlags modeFlags) Constructors in org.jruby.util.io with parameters of type ModeFlags
FileResource.openChannel(int, int)instead