| Package | Description |
|---|---|
| org.jruby.java.proxies | |
| org.jruby.javasupport |
| Modifier and Type | Method and Description |
|---|---|
ConcreteJavaProxy.SplitCtorData |
ConcreteJavaProxy.splitInitialized(RubyClass base,
IRubyObject[] args,
Block block,
Java.JCtorCache jcc)
Used by reified classes, this method is tightly coupled with RealClassGenerator, finishInitialize
Do not refactor without looking at RCG
|
| Constructor and Description |
|---|
SplitCtorData(IRubyObject[] args,
Java.JCtorCache cache,
Ruby runtime)
Picks and converts arguments for the super call
Leaves ctorIndex and arguments ready for the super call
|
SplitCtorData(IRubyObject[] args,
Java.JCtorCache cache,
Ruby runtime,
AbstractIRMethod method,
SplitSuperState<?> state,
Block block) |
SplitCtorData(IRubyObject[] args,
Java.JCtorCache cache,
Ruby runtime,
AbstractIRMethod method,
java.lang.String name,
Block block) |
| Modifier and Type | Method and Description |
|---|---|
static int |
Java.JCreateMethod.forTypes(IRubyObject[] args,
Java.JCtorCache cache,
Ruby runtime)
Disambiguate which ctor index to call from the given cache
|
Copyright © 2001-2024 JRuby. All Rights Reserved.