java.lang.Object
org.jruby.JarBootstrapMain
Deprecated, for removal: This API element is subject to removal in a future version.
-
Field Summary
FieldsModifier and TypeFieldDescriptionstatic final StringDeprecated, for removal: This API element is subject to removal in a future version. -
Constructor Summary
ConstructorsConstructorDescriptionDeprecated, for removal: This API element is subject to removal in a future version. -
Method Summary
-
Field Details
-
JAR_BOOTSTRAP
Deprecated, for removal: This API element is subject to removal in a future version.- See Also:
-
-
Constructor Details
-
JarBootstrapMain
public JarBootstrapMain()Deprecated, for removal: This API element is subject to removal in a future version.
-
-
Method Details
-
main
Deprecated, for removal: This API element is subject to removal in a future version.
-
JarBootstrapMaininstead.